# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/device.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/device.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spacex.api.common.status import status_pb2 as spacex_dot_api_dot_common_dot_status_dot_status__pb2
from spacex.api.device import command_pb2 as spacex_dot_api_dot_device_dot_command__pb2
from spacex.api.device import common_pb2 as spacex_dot_api_dot_device_dot_common__pb2
from spacex.api.device import dish_pb2 as spacex_dot_api_dot_device_dot_dish__pb2
from spacex.api.device import transceiver_pb2 as spacex_dot_api_dot_device_dot_transceiver__pb2
from spacex.api.device import wifi_pb2 as spacex_dot_api_dot_device_dot_wifi__pb2
from spacex.api.device.services.unlock import service_pb2 as spacex_dot_api_dot_device_dot_services_dot_unlock_dot_service__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1espacex/api/device/device.proto\x12\x11SpaceX.API.Device\x1a%spacex/api/common/status/status.proto\x1a\x1fspacex/api/device/command.proto\x1a\x1espacex/api/device/common.proto\x1a\x1cspacex/api/device/dish.proto\x1a#spacex/api/device/transceiver.proto\x1a\x1cspacex/api/device/wifi.proto\x1a/spacex/api/device/services/unlock/service.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x92\x01\n\x08ToDevice\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32\x1a.SpaceX.API.Device.RequestH\x00R\x07request\x12\x43\n\x0chealth_check\x18\x02 \x01(\x0b\x32\x1e.SpaceX.API.Device.HealthCheckH\x00R\x0bhealthCheckB\t\n\x07message\"\xc9\x01\n\nFromDevice\x12\x39\n\x08response\x18\x01 \x01(\x0b\x32\x1b.SpaceX.API.Device.ResponseH\x00R\x08response\x12\x30\n\x05\x65vent\x18\x02 \x01(\x0b\x32\x18.SpaceX.API.Device.EventH\x00R\x05\x65vent\x12\x43\n\x0chealth_check\x18\x03 \x01(\x0b\x32\x1e.SpaceX.API.Device.HealthCheckH\x00R\x0bhealthCheckB\t\n\x07message\"\xc0\x01\n\x10SensitiveCommand\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x1b\n\ttarget_id\x18\x02 \x01(\tR\x08targetId\x12J\n\x0cget_location\x18\x03 \x01(\x0b\x32%.SpaceX.API.Device.GetLocationRequestH\x00R\x0bgetLocationB\t\n\x07request\"\r\n\x0bHealthCheck\"\x9d\x39\n\x07Request\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x19\n\x08\x65poch_id\x18\x0e \x01(\x04R\x07\x65pochId\x12\x1b\n\ttarget_id\x18\r \x01(\tR\x08targetId\x12\x46\n\x0esigned_request\x18\x0f \x01(\x0b\x32\x1d.SpaceX.API.Device.SignedDataH\x00R\rsignedRequest\x12\x46\n\x0bget_next_id\x18\xee\x07 \x01(\x0b\x32#.SpaceX.API.Device.GetNextIdRequestH\x00R\tgetNextId\x12M\n\x11sensitive_request\x18\xb6\x08 \x01(\x0b\x32\x1d.SpaceX.API.Device.SignedDataH\x00R\x10sensitiveRequest\x12M\n\x0c\x61uthenticate\x18\xed\x07 \x01(\x0b\x32&.SpaceX.API.Device.AuthenticateRequestH\x00R\x0c\x61uthenticate\x12[\n\x12\x65nable_debug_telem\x18\x8a\x08 \x01(\x0b\x32*.SpaceX.API.Device.EnableDebugTelemRequestH\x00R\x10\x65nableDebugTelem\x12N\n\rfactory_reset\x18\xf3\x07 \x01(\x0b\x32&.SpaceX.API.Device.FactoryResetRequestH\x00R\x0c\x66\x61\x63toryReset\x12R\n\x0fget_device_info\x18\xf0\x07 \x01(\x0b\x32\'.SpaceX.API.Device.GetDeviceInfoRequestH\x00R\rgetDeviceInfo\x12H\n\x0bget_history\x18\xef\x07 \x01(\x0b\x32$.SpaceX.API.Device.GetHistoryRequestH\x00R\ngetHistory\x12<\n\x07get_log\x18\xf4\x07 \x01(\x0b\x32 .SpaceX.API.Device.GetLogRequestH\x00R\x06getLog\x12g\n\x16get_network_interfaces\x18\xf7\x07 \x01(\x0b\x32..SpaceX.API.Device.GetNetworkInterfacesRequestH\x00R\x14getNetworkInterfaces\x12?\n\x08get_ping\x18\xf1\x07 \x01(\x0b\x32!.SpaceX.API.Device.GetPingRequestH\x00R\x07getPing\x12\x42\n\tping_host\x18\xf8\x07 \x01(\x0b\x32\".SpaceX.API.Device.PingHostRequestH\x00R\x08pingHost\x12\x45\n\nget_status\x18\xec\x07 \x01(\x0b\x32#.SpaceX.API.Device.GetStatusRequestH\x00R\tgetStatus\x12;\n\x06reboot\x18\xe9\x07 \x01(\x0b\x32 .SpaceX.API.Device.RebootRequestH\x00R\x06reboot\x12<\n\x07set_sku\x18\xf5\x07 \x01(\x0b\x32 .SpaceX.API.Device.SetSkuRequestH\x00R\x06setSku\x12U\n\x10set_trusted_keys\x18\xf2\x07 \x01(\x0b\x32(.SpaceX.API.Device.SetTrustedKeysRequestH\x00R\x0esetTrustedKeys\x12\x45\n\nspeed_test\x18\xeb\x07 \x01(\x0b\x32#.SpaceX.API.Device.SpeedTestRequestH\x00R\tspeedTest\x12;\n\x06update\x18\xf6\x07 \x01(\x0b\x32 .SpaceX.API.Device.UpdateRequestH\x00R\x06update\x12K\n\x0cget_location\x18\xf9\x07 \x01(\x0b\x32%.SpaceX.API.Device.GetLocationRequestH\x00R\x0bgetLocation\x12L\n\rget_heap_dump\x18\xfb\x07 \x01(\x0b\x32%.SpaceX.API.Device.GetHeapDumpRequestH\x00R\x0bgetHeapDump\x12T\n\x0frestart_control\x18\xfc\x07 \x01(\x0b\x32(.SpaceX.API.Device.RestartControlRequestH\x00R\x0erestartControl\x12\x35\n\x04\x66use\x18\xfd\x07 \x01(\x0b\x32\x1e.SpaceX.API.Device.FuseRequestH\x00R\x04\x66use\x12\x61\n\x14get_persistent_stats\x18\xfe\x07 \x01(\x0b\x32,.SpaceX.API.Device.GetPersistentStatsRequestH\x00R\x12getPersistentStats\x12T\n\x0fget_connections\x18\xff\x07 \x01(\x0b\x32(.SpaceX.API.Device.GetConnectionsRequestH\x00R\x0egetConnections\x12T\n\x0fstart_speedtest\x18\x83\x08 \x01(\x0b\x32(.SpaceX.API.Device.StartSpeedtestRequestH\x00R\x0estartSpeedtest\x12\x61\n\x14get_speedtest_status\x18\x84\x08 \x01(\x0b\x32,.SpaceX.API.Device.GetSpeedtestStatusRequestH\x00R\x12getSpeedtestStatus\x12j\n\x17report_client_speedtest\x18\x85\x08 \x01(\x0b\x32/.SpaceX.API.Device.ReportClientSpeedtestRequestH\x00R\x15reportClientSpeedtest\x12\x62\n\x13initiate_remote_ssh\x18\x86\x08 \x01(\x0b\x32+.SpaceX.API.Device.InitiateRemoteSshRequestB\x02\x18\x01H\x00R\x11initiateRemoteSsh\x12\x42\n\tself_test\x18\x87\x08 \x01(\x0b\x32\".SpaceX.API.Device.SelfTestRequestH\x00R\x08selfTest\x12L\n\rset_test_mode\x18\x88\x08 \x01(\x0b\x32%.SpaceX.API.Device.SetTestModeRequestH\x00R\x0bsetTestMode\x12T\n\x0fsoftware_update\x18\x89\x08 \x01(\x0b\x32(.SpaceX.API.Device.SoftwareUpdateRequestH\x00R\x0esoftwareUpdate\x12\x45\n\niq_capture\x18\x8b\x08 \x01(\x0b\x32#.SpaceX.API.Device.IQCaptureRequestH\x00R\tiqCapture\x12R\n\x0fget_radio_stats\x18\x8c\x08 \x01(\x0b\x32\'.SpaceX.API.Device.GetRadioStatsRequestH\x00R\rgetRadioStats\x12\x38\n\x04time\x18\x8d\x08 \x01(\x0b\x32!.SpaceX.API.Device.GetTimeRequestH\x00R\x04time\x12U\n\x10run_iperf_server\x18\x8e\x08 \x01(\x0b\x32(.SpaceX.API.Device.RunIperfServerRequestH\x00R\x0erunIperfServer\x12\x64\n\x15tcp_connectivity_test\x18\x8f\x08 \x01(\x0b\x32-.SpaceX.API.Device.TcpConnectivityTestRequestH\x00R\x13tcpConnectivityTest\x12\x64\n\x15udp_connectivity_test\x18\x90\x08 \x01(\x0b\x32-.SpaceX.API.Device.UdpConnectivityTestRequestH\x00R\x13udpConnectivityTest\x12\x42\n\tdish_stow\x18\xd2\x0f \x01(\x0b\x32\".SpaceX.API.Device.DishStowRequestH\x00R\x08\x64ishStow\x12_\n\x14start_dish_self_test\x18\xdc\x0f \x01(\x0b\x32+.SpaceX.API.Device.StartDishSelfTestRequestH\x00R\x11startDishSelfTest\x12U\n\x10\x64ish_get_context\x18\xd3\x0f \x01(\x0b\x32(.SpaceX.API.Device.DishGetContextRequestH\x00R\x0e\x64ishGetContext\x12k\n\x18\x64ish_get_obstruction_map\x18\xd8\x0f \x01(\x0b\x32/.SpaceX.API.Device.DishGetObstructionMapRequestH\x00R\x15\x64ishGetObstructionMap\x12I\n\x0c\x64ish_set_emc\x18\xd7\x0f \x01(\x0b\x32$.SpaceX.API.Device.DishSetEmcRequestH\x00R\ndishSetEmc\x12I\n\x0c\x64ish_get_emc\x18\xd9\x0f \x01(\x0b\x32$.SpaceX.API.Device.DishGetEmcRequestH\x00R\ndishGetEmc\x12R\n\x0f\x64ish_set_config\x18\xda\x0f \x01(\x0b\x32\'.SpaceX.API.Device.DishSetConfigRequestH\x00R\rdishSetConfig\x12R\n\x0f\x64ish_get_config\x18\xdb\x0f \x01(\x0b\x32\'.SpaceX.API.Device.DishGetConfigRequestH\x00R\rdishGetConfig\x12R\n\x0f\x64ish_power_save\x18\xdd\x0f \x01(\x0b\x32\'.SpaceX.API.Device.DishPowerSaveRequestH\x00R\rdishPowerSave\x12U\n\x10\x64ish_inhibit_gps\x18\xde\x0f \x01(\x0b\x32(.SpaceX.API.Device.DishInhibitGpsRequestH\x00R\x0e\x64ishInhibitGps\x12L\n\rdish_get_data\x18\xdf\x0f \x01(\x0b\x32%.SpaceX.API.Device.DishGetDataRequestH\x00R\x0b\x64ishGetData\x12q\n\x1a\x64ish_clear_obstruction_map\x18\xe1\x0f \x01(\x0b\x32\x31.SpaceX.API.Device.DishClearObstructionMapRequestH\x00R\x17\x64ishClearObstructionMap\x12s\n\x1c\x64ish_set_max_power_test_mode\x18\xe2\x0f \x01(\x0b\x32\x31.SpaceX.API.Device.DishSetMaxPowerTestModeRequestH\x00R\x17\x64ishSetMaxPowerTestMode\x12h\n\x17\x64ish_activate_rssi_scan\x18\xe3\x0f \x01(\x0b\x32..SpaceX.API.Device.DishActivateRssiScanRequestH\x00R\x14\x64ishActivateRssiScan\x12l\n\x19\x64ish_get_rssi_scan_result\x18\xe4\x0f \x01(\x0b\x32/.SpaceX.API.Device.DishGetRssiScanResultRequestH\x00R\x15\x64ishGetRssiScanResult\x12[\n\x12\x64ish_factory_reset\x18\xe5\x0f \x01(\x0b\x32*.SpaceX.API.Device.DishFactoryResetRequestH\x00R\x10\x64ishFactoryReset\x12K\n\x0creset_button\x18\xe6\x0f \x01(\x0b\x32%.SpaceX.API.Device.ResetButtonRequestH\x00R\x0bresetButton\x12U\n\x10wifi_get_clients\x18\xba\x17 \x01(\x0b\x32(.SpaceX.API.Device.WifiGetClientsRequestH\x00R\x0ewifiGetClients\x12\x62\n\x15wifi_get_ping_metrics\x18\xbf\x17 \x01(\x0b\x32,.SpaceX.API.Device.WifiGetPingMetricsRequestH\x00R\x12wifiGetPingMetrics\x12R\n\x0fwifi_set_config\x18\xb9\x17 \x01(\x0b\x32\'.SpaceX.API.Device.WifiSetConfigRequestH\x00R\rwifiSetConfig\x12R\n\x0fwifi_get_config\x18\xc1\x17 \x01(\x0b\x32\'.SpaceX.API.Device.WifiGetConfigRequestH\x00R\rwifiGetConfig\x12\x45\n\nwifi_setup\x18\xbb\x17 \x01(\x0b\x32#.SpaceX.API.Device.WifiSetupRequestH\x00R\twifiSetup\x12o\n\x1awifi_set_mesh_device_trust\x18\xc4\x17 \x01(\x0b\x32\x30.SpaceX.API.Device.WifiSetMeshDeviceTrustRequestH\x00R\x16wifiSetMeshDeviceTrust\x12\x63\n\x14wifi_set_mesh_config\x18\xc5\x17 \x01(\x0b\x32+.SpaceX.API.Device.WifiSetMeshConfigRequestB\x02\x18\x01H\x00R\x11wifiSetMeshConfig\x12h\n\x17wifi_get_client_history\x18\xc7\x17 \x01(\x0b\x32..SpaceX.API.Device.WifiGetClientHistoryRequestH\x00R\x14wifiGetClientHistory\x12o\n\x1awifi_set_client_given_name\x18\xc9\x17 \x01(\x0b\x32\x30.SpaceX.API.Device.WifiSetClientGivenNameRequestH\x00R\x16wifiSetClientGivenName\x12t\n\x1bwifi_set_aviation_conformed\x18\xc8\x17 \x01(\x0b\x32\x32.SpaceX.API.Device.WifiSetAviationConformedRequestH\x00R\x18wifiSetAviationConformed\x12O\n\x0ewifi_self_test\x18\xca\x17 \x01(\x0b\x32&.SpaceX.API.Device.WifiSelfTestRequestH\x00R\x0cwifiSelfTest\x12Y\n\x12wifi_run_self_test\x18\xd4\x17 \x01(\x0b\x32).SpaceX.API.Device.WifiRunSelfTestRequestH\x00R\x0fwifiRunSelfTest\x12\x64\n\x15wifi_calibration_mode\x18\xcb\x17 \x01(\x0b\x32-.SpaceX.API.Device.WifiCalibrationModeRequestH\x00R\x13wifiCalibrationMode\x12R\n\x0fwifi_guest_info\x18\xcc\x17 \x01(\x0b\x32\'.SpaceX.API.Device.WifiGuestInfoRequestH\x00R\rwifiGuestInfo\x12I\n\x0cwifi_rf_test\x18\xcd\x17 \x01(\x0b\x32$.SpaceX.API.Device.WifiRfTestRequestH\x00R\nwifiRfTest\x12X\n\x11wifi_get_firewall\x18\xd0\x17 \x01(\x0b\x32).SpaceX.API.Device.WifiGetFirewallRequestH\x00R\x0fwifiGetFirewall\x12t\n\x1bwifi_toggle_poe_negotiation\x18\xd1\x17 \x01(\x0b\x32\x32.SpaceX.API.Device.WifiTogglePoeNegotiationRequestH\x00R\x18wifiTogglePoeNegotiation\x12n\n\x19wifi_factory_test_command\x18\xd2\x17 \x01(\x0b\x32\x30.SpaceX.API.Device.WifiFactoryTestCommandRequestH\x00R\x16wifiFactoryTestCommand\x12u\n\x1cwifi_start_local_telem_proxy\x18\xd3\x17 \x01(\x0b\x32\x32.SpaceX.API.Device.WifiStartLocalTelemProxyRequestH\x00R\x18wifiStartLocalTelemProxy\x12^\n\x13wifi_backhaul_stats\x18\xd5\x17 \x01(\x0b\x32+.SpaceX.API.Device.WifiBackhaulStatsRequestH\x00R\x11wifiBackhaulStats\x12q\n\x1awifi_toggle_umbilical_mode\x18\xd6\x17 \x01(\x0b\x32\x31.SpaceX.API.Device.WifiToggleUmbilicalModeRequestH\x00R\x17wifiToggleUmbilicalMode\x12w\n\x1ctransceiver_if_loopback_test\x18\xa1\x1f \x01(\x0b\x32\x33.SpaceX.API.Device.TransceiverIFLoopbackTestRequestH\x00R\x19transceiverIfLoopbackTest\x12g\n\x16transceiver_get_status\x18\xa3\x1f \x01(\x0b\x32..SpaceX.API.Device.TransceiverGetStatusRequestH\x00R\x14transceiverGetStatus\x12p\n\x19transceiver_get_telemetry\x18\xa4\x1f \x01(\x0b\x32\x31.SpaceX.API.Device.TransceiverGetTelemetryRequestH\x00R\x17transceiverGetTelemetry\x12[\n\x0cstart_unlock\x18\x88\' \x01(\x0b\x32\x35.SpaceX.API.Device.Services.Unlock.StartUnlockRequestH\x00R\x0bstartUnlock\x12^\n\rfinish_unlock\x18\x89\' \x01(\x0b\x32\x36.SpaceX.API.Device.Services.Unlock.FinishUnlockRequestH\x00R\x0c\x66inishUnlock\x12T\n\x0fget_diagnostics\x18\xf0. \x01(\x0b\x32(.SpaceX.API.Device.GetDiagnosticsRequestH\x00R\x0egetDiagnosticsB\t\n\x07requestJ\x06\x08\xfa\x07\x10\xfb\x07J\x06\x08\x81\x08\x10\x82\x08J\x06\x08\x82\x08\x10\x83\x08J\x06\x08\xe0\x0f\x10\xe1\x0fJ\x06\x08\xc3\x17\x10\xc4\x17J\x06\x08\xc6\x17\x10\xc7\x17J\x06\x08\x82\x19\x10\x83\x19\"\xe1\x32\n\x08Response\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x31\n\x06status\x18\x02 \x01(\x0b\x32\x19.SpaceX.API.Status.StatusR\x06status\x12\x1f\n\x0b\x61pi_version\x18\x03 \x01(\x04R\napiVersion\x12G\n\x0bget_next_id\x18\xee\x07 \x01(\x0b\x32$.SpaceX.API.Device.GetNextIdResponseH\x00R\tgetNextId\x12\\\n\x12\x65nable_debug_telem\x18\x8a\x08 \x01(\x0b\x32+.SpaceX.API.Device.EnableDebugTelemResponseH\x00R\x10\x65nableDebugTelem\x12O\n\rfactory_reset\x18\xf3\x07 \x01(\x0b\x32\'.SpaceX.API.Device.FactoryResetResponseH\x00R\x0c\x66\x61\x63toryReset\x12S\n\x0fget_device_info\x18\xec\x07 \x01(\x0b\x32(.SpaceX.API.Device.GetDeviceInfoResponseH\x00R\rgetDeviceInfo\x12=\n\x07get_log\x18\xf4\x07 \x01(\x0b\x32!.SpaceX.API.Device.GetLogResponseH\x00R\x06getLog\x12h\n\x16get_network_interfaces\x18\xf7\x07 \x01(\x0b\x32/.SpaceX.API.Device.GetNetworkInterfacesResponseH\x00R\x14getNetworkInterfaces\x12@\n\x08get_ping\x18\xf1\x07 \x01(\x0b\x32\".SpaceX.API.Device.GetPingResponseH\x00R\x07getPing\x12\x43\n\tping_host\x18\xf8\x07 \x01(\x0b\x32#.SpaceX.API.Device.PingHostResponseH\x00R\x08pingHost\x12<\n\x06reboot\x18\xe9\x07 \x01(\x0b\x32!.SpaceX.API.Device.RebootResponseH\x00R\x06reboot\x12\x46\n\nspeed_test\x18\xeb\x07 \x01(\x0b\x32$.SpaceX.API.Device.SpeedTestResponseH\x00R\tspeedTest\x12=\n\x07set_sku\x18\xf5\x07 \x01(\x0b\x32!.SpaceX.API.Device.SetSkuResponseH\x00R\x06setSku\x12V\n\x10set_trusted_keys\x18\xf2\x07 \x01(\x0b\x32).SpaceX.API.Device.SetTrustedKeysResponseH\x00R\x0esetTrustedKeys\x12<\n\x06update\x18\xf6\x07 \x01(\x0b\x32!.SpaceX.API.Device.UpdateResponseH\x00R\x06update\x12L\n\x0cget_location\x18\xf9\x07 \x01(\x0b\x32&.SpaceX.API.Device.GetLocationResponseH\x00R\x0bgetLocation\x12M\n\rget_heap_dump\x18\xfb\x07 \x01(\x0b\x32&.SpaceX.API.Device.GetHeapDumpResponseH\x00R\x0bgetHeapDump\x12U\n\x0frestart_control\x18\xfc\x07 \x01(\x0b\x32).SpaceX.API.Device.RestartControlResponseH\x00R\x0erestartControl\x12\x36\n\x04\x66use\x18\xfd\x07 \x01(\x0b\x32\x1f.SpaceX.API.Device.FuseResponseH\x00R\x04\x66use\x12U\n\x0fget_connections\x18\xff\x07 \x01(\x0b\x32).SpaceX.API.Device.GetConnectionsResponseH\x00R\x0egetConnections\x12U\n\x0fstart_speedtest\x18\x83\x08 \x01(\x0b\x32).SpaceX.API.Device.StartSpeedtestResponseH\x00R\x0estartSpeedtest\x12\x62\n\x14get_speedtest_status\x18\x84\x08 \x01(\x0b\x32-.SpaceX.API.Device.GetSpeedtestStatusResponseH\x00R\x12getSpeedtestStatus\x12k\n\x17report_client_speedtest\x18\x85\x08 \x01(\x0b\x32\x30.SpaceX.API.Device.ReportClientSpeedtestResponseH\x00R\x15reportClientSpeedtest\x12\x63\n\x13initiate_remote_ssh\x18\x86\x08 \x01(\x0b\x32,.SpaceX.API.Device.InitiateRemoteSshResponseB\x02\x18\x01H\x00R\x11initiateRemoteSsh\x12\x43\n\tself_test\x18\x87\x08 \x01(\x0b\x32#.SpaceX.API.Device.SelfTestResponseH\x00R\x08selfTest\x12M\n\rset_test_mode\x18\x88\x08 \x01(\x0b\x32&.SpaceX.API.Device.SetTestModeResponseH\x00R\x0bsetTestMode\x12U\n\x0fsoftware_update\x18\x89\x08 \x01(\x0b\x32).SpaceX.API.Device.SoftwareUpdateResponseH\x00R\x0esoftwareUpdate\x12S\n\x0fget_radio_stats\x18\x8b\x08 \x01(\x0b\x32(.SpaceX.API.Device.GetRadioStatsResponseH\x00R\rgetRadioStats\x12\x39\n\x04time\x18\x8d\x08 \x01(\x0b\x32\".SpaceX.API.Device.GetTimeResponseH\x00R\x04time\x12V\n\x10run_iperf_server\x18\x8e\x08 \x01(\x0b\x32).SpaceX.API.Device.RunIperfServerResponseH\x00R\x0erunIperfServer\x12[\n\x11\x64ish_authenticate\x18\xd5\x0f \x01(\x0b\x32+.SpaceX.API.Device.DishAuthenticateResponseH\x00R\x10\x64ishAuthenticate\x12V\n\x10\x64ish_get_context\x18\xd3\x0f \x01(\x0b\x32).SpaceX.API.Device.DishGetContextResponseH\x00R\x0e\x64ishGetContext\x12V\n\x10\x64ish_get_history\x18\xd6\x0f \x01(\x0b\x32).SpaceX.API.Device.DishGetHistoryResponseH\x00R\x0e\x64ishGetHistory\x12S\n\x0f\x64ish_get_status\x18\xd4\x0f \x01(\x0b\x32(.SpaceX.API.Device.DishGetStatusResponseH\x00R\rdishGetStatus\x12l\n\x18\x64ish_get_obstruction_map\x18\xd8\x0f \x01(\x0b\x32\x30.SpaceX.API.Device.DishGetObstructionMapResponseH\x00R\x15\x64ishGetObstructionMap\x12\x43\n\tdish_stow\x18\xd2\x0f \x01(\x0b\x32#.SpaceX.API.Device.DishStowResponseH\x00R\x08\x64ishStow\x12`\n\x14start_dish_self_test\x18\xdc\x0f \x01(\x0b\x32,.SpaceX.API.Device.StartDishSelfTestResponseH\x00R\x11startDishSelfTest\x12J\n\x0c\x64ish_set_emc\x18\xd7\x0f \x01(\x0b\x32%.SpaceX.API.Device.DishSetEmcResponseH\x00R\ndishSetEmc\x12J\n\x0c\x64ish_get_emc\x18\xd9\x0f \x01(\x0b\x32%.SpaceX.API.Device.DishGetEmcResponseH\x00R\ndishGetEmc\x12S\n\x0f\x64ish_set_config\x18\xda\x0f \x01(\x0b\x32(.SpaceX.API.Device.DishSetConfigResponseH\x00R\rdishSetConfig\x12S\n\x0f\x64ish_get_config\x18\xdb\x0f \x01(\x0b\x32(.SpaceX.API.Device.DishGetConfigResponseH\x00R\rdishGetConfig\x12V\n\x10\x64ish_inhibit_gps\x18\xdd\x0f \x01(\x0b\x32).SpaceX.API.Device.DishInhibitGpsResponseH\x00R\x0e\x64ishInhibitGps\x12r\n\x1a\x64ish_clear_obstruction_map\x18\xdf\x0f \x01(\x0b\x32\x32.SpaceX.API.Device.DishClearObstructionMapResponseH\x00R\x17\x64ishClearObstructionMap\x12t\n\x1c\x64ish_set_max_power_test_mode\x18\xe2\x0f \x01(\x0b\x32\x32.SpaceX.API.Device.DishSetMaxPowerTestModeResponseH\x00R\x17\x64ishSetMaxPowerTestMode\x12i\n\x17\x64ish_activate_rssi_scan\x18\xe3\x0f \x01(\x0b\x32/.SpaceX.API.Device.DishActivateRssiScanResponseH\x00R\x14\x64ishActivateRssiScan\x12m\n\x19\x64ish_get_rssi_scan_result\x18\xe4\x0f \x01(\x0b\x32\x30.SpaceX.API.Device.DishGetRssiScanResultResponseH\x00R\x15\x64ishGetRssiScanResult\x12\\\n\x12\x64ish_factory_reset\x18\xe5\x0f \x01(\x0b\x32+.SpaceX.API.Device.DishFactoryResetResponseH\x00R\x10\x64ishFactoryReset\x12L\n\x0creset_button\x18\xe6\x0f \x01(\x0b\x32&.SpaceX.API.Device.ResetButtonResponseH\x00R\x0bresetButton\x12[\n\x11wifi_authenticate\x18\xbd\x17 \x01(\x0b\x32+.SpaceX.API.Device.WifiAuthenticateResponseH\x00R\x10wifiAuthenticate\x12V\n\x10wifi_get_clients\x18\xba\x17 \x01(\x0b\x32).SpaceX.API.Device.WifiGetClientsResponseH\x00R\x0ewifiGetClients\x12V\n\x10wifi_get_history\x18\xbe\x17 \x01(\x0b\x32).SpaceX.API.Device.WifiGetHistoryResponseH\x00R\x0ewifiGetHistory\x12\x63\n\x15wifi_get_ping_metrics\x18\xbf\x17 \x01(\x0b\x32-.SpaceX.API.Device.WifiGetPingMetricsResponseH\x00R\x12wifiGetPingMetrics\x12S\n\x0fwifi_get_status\x18\xbc\x17 \x01(\x0b\x32(.SpaceX.API.Device.WifiGetStatusResponseH\x00R\rwifiGetStatus\x12S\n\x0fwifi_set_config\x18\xb9\x17 \x01(\x0b\x32(.SpaceX.API.Device.WifiSetConfigResponseH\x00R\rwifiSetConfig\x12S\n\x0fwifi_get_config\x18\xc1\x17 \x01(\x0b\x32(.SpaceX.API.Device.WifiGetConfigResponseH\x00R\rwifiGetConfig\x12\x46\n\nwifi_setup\x18\xbb\x17 \x01(\x0b\x32$.SpaceX.API.Device.WifiSetupResponseH\x00R\twifiSetup\x12o\n\x19wifi_get_persistent_stats\x18\xce\x17 \x01(\x0b\x32\x31.SpaceX.API.Device.WifiGetPersistentStatsResponseH\x00R\x16wifiGetPersistentStats\x12p\n\x1awifi_set_mesh_device_trust\x18\xc4\x17 \x01(\x0b\x32\x31.SpaceX.API.Device.WifiSetMeshDeviceTrustResponseH\x00R\x16wifiSetMeshDeviceTrust\x12\x64\n\x14wifi_set_mesh_config\x18\xc5\x17 \x01(\x0b\x32,.SpaceX.API.Device.WifiSetMeshConfigResponseB\x02\x18\x01H\x00R\x11wifiSetMeshConfig\x12i\n\x17wifi_get_client_history\x18\xc7\x17 \x01(\x0b\x32/.SpaceX.API.Device.WifiGetClientHistoryResponseH\x00R\x14wifiGetClientHistory\x12P\n\x0ewifi_self_test\x18\xc8\x17 \x01(\x0b\x32\'.SpaceX.API.Device.WifiSelfTestResponseH\x00R\x0cwifiSelfTest\x12S\n\x0fwifi_guest_info\x18\xcc\x17 \x01(\x0b\x32(.SpaceX.API.Device.WifiGuestInfoResponseH\x00R\rwifiGuestInfo\x12J\n\x0cwifi_rf_test\x18\xcd\x17 \x01(\x0b\x32%.SpaceX.API.Device.WifiRfTestResponseH\x00R\nwifiRfTest\x12Y\n\x11wifi_get_firewall\x18\xd0\x17 \x01(\x0b\x32*.SpaceX.API.Device.WifiGetFirewallResponseH\x00R\x0fwifiGetFirewall\x12o\n\x19wifi_factory_test_command\x18\xd1\x17 \x01(\x0b\x32\x31.SpaceX.API.Device.WifiFactoryTestCommandResponseH\x00R\x16wifiFactoryTestCommand\x12_\n\x13wifi_backhaul_stats\x18\xd2\x17 \x01(\x0b\x32,.SpaceX.API.Device.WifiBackhaulStatsResponseH\x00R\x11wifiBackhaulStats\x12x\n\x1ctransceiver_if_loopback_test\x18\xa1\x1f \x01(\x0b\x32\x34.SpaceX.API.Device.TransceiverIFLoopbackTestResponseH\x00R\x19transceiverIfLoopbackTest\x12h\n\x16transceiver_get_status\x18\xa3\x1f \x01(\x0b\x32/.SpaceX.API.Device.TransceiverGetStatusResponseH\x00R\x14transceiverGetStatus\x12q\n\x19transceiver_get_telemetry\x18\xa4\x1f \x01(\x0b\x32\x32.SpaceX.API.Device.TransceiverGetTelemetryResponseH\x00R\x17transceiverGetTelemetry\x12\\\n\x0cstart_unlock\x18\x88\' \x01(\x0b\x32\x36.SpaceX.API.Device.Services.Unlock.StartUnlockResponseH\x00R\x0bstartUnlock\x12_\n\rfinish_unlock\x18\x89\' \x01(\x0b\x32\x37.SpaceX.API.Device.Services.Unlock.FinishUnlockResponseH\x00R\x0c\x66inishUnlock\x12\x62\n\x14wifi_get_diagnostics\x18\xf0. \x01(\x0b\x32-.SpaceX.API.Device.WifiGetDiagnosticsResponseH\x00R\x12wifiGetDiagnostics\x12\x62\n\x14\x64ish_get_diagnostics\x18\xf1. \x01(\x0b\x32-.SpaceX.API.Device.DishGetDiagnosticsResponseH\x00R\x12\x64ishGetDiagnosticsB\n\n\x08responseJ\x06\x08\xfa\x07\x10\xfb\x07J\x06\x08\x82\x08\x10\x83\x08J\x06\x08\xde\x0f\x10\xdf\x0fJ\x06\x08\xe9\x0f\x10\xea\x0fJ\x06\x08\xc0\x17\x10\xc1\x17J\x06\x08\xc3\x17\x10\xc4\x17J\x06\x08\xc6\x17\x10\xc7\x17J\x06\x08\x83\x19\x10\x84\x19\"\x83\x03\n\x05\x45vent\x12l\n\x19wifi_new_client_connected\x18\xb9\x17 \x01(\x0b\x32..SpaceX.API.Device.WifiNewClientConnectedEventH\x00R\x16wifiNewClientConnected\x12_\n\x14wifi_account_bonding\x18\xba\x17 \x01(\x0b\x32*.SpaceX.API.Device.WifiAccountBondingEventH\x00R\x12wifiAccountBonding\x12J\n\rwifi_new_peer\x18\xbb\x17 \x01(\x0b\x32#.SpaceX.API.Device.WifiNewPeerEventH\x00R\x0bwifiNewPeer\x12V\n\x11wifi_cloud_status\x18\xbc\x17 \x01(\x0b\x32\'.SpaceX.API.Device.WifiCloudStatusEventH\x00R\x0fwifiCloudStatusB\x07\n\x05\x65vent\"\xb2\x01\n\x14WifiCloudStatusEvent\x12\x1f\n\x0b\x61pi_version\x18\x04 \x01(\rR\napiVersion\x12-\n\x13\x64irect_link_to_dish\x18\x01 \x01(\x08R\x10\x64irectLinkToDish\x12)\n\x10hardware_version\x18\x02 \x01(\tR\x0fhardwareVersion\x12\x1f\n\x0bis_bypassed\x18\x03 \x01(\x08R\nisBypassed\"8\n\x17\x45nableDebugTelemRequest\x12\x1d\n\nduration_m\x18\x01 \x01(\rR\tdurationM\"\x1a\n\x18\x45nableDebugTelemResponse\"\x15\n\x13\x46\x61\x63toryResetRequest\"\x16\n\x14\x46\x61\x63toryResetResponse\"\x10\n\x0eGetTimeRequest\".\n\x0fGetTimeResponse\x12\x1b\n\tunix_nano\x18\x01 \x01(\x03R\x08unixNano\"4\n\x0b\x46useRequest\x12%\n\x0eprevent_reboot\x18\x01 \x01(\x08R\rpreventReboot\"\x0e\n\x0c\x46useResponse\"\x13\n\x11GetHistoryRequest\"\x0f\n\rGetLogRequest\"\xf9\x02\n\x0eGetLogResponse\x12@\n\x07\x63urrent\x18\x04 \x01(\x0b\x32&.SpaceX.API.Device.GetLogResponse.LogsR\x07\x63urrent\x12<\n\x05saved\x18\x05 \x01(\x0b\x32&.SpaceX.API.Device.GetLogResponse.LogsR\x05saved\x12\x1a\n\x06syslog\x18\x01 \x01(\tB\x02\x18\x01R\x06syslog\x12#\n\x0boffline_log\x18\x02 \x01(\tB\x02\x18\x01R\nofflineLog\x12)\n\x0epersistent_log\x18\x03 \x01(\tB\x02\x18\x01R\rpersistentLog\x1a{\n\x04Logs\x12\x16\n\x06syslog\x18\x01 \x01(\tR\x06syslog\x12\x14\n\x05\x64mesg\x18\x02 \x01(\tR\x05\x64mesg\x12!\n\x0ckernel_panic\x18\x03 \x01(\tR\x0bkernelPanic\x12\"\n\rmtk_eth_procs\x18\x04 \x01(\tR\x0bmtkEthProcs\"\x10\n\x0eGetPingRequest\"\xb7\x01\n\x0fGetPingResponse\x12I\n\x07results\x18\x01 \x03(\x0b\x32/.SpaceX.API.Device.GetPingResponse.ResultsEntryR\x07results\x1aY\n\x0cResultsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32\x1d.SpaceX.API.Device.PingResultR\x05value:\x02\x38\x01\"?\n\x0fPingHostRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x03 \x01(\tR\x07\x61\x64\x64ress\x12\x12\n\x04size\x18\x04 \x01(\rR\x04size\"I\n\x10PingHostResponse\x12\x35\n\x06result\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.PingResultR\x06result\"\x12\n\x10GetStatusRequest\"\x0f\n\rRebootRequest\"\x10\n\x0eRebootResponse\"\x8f\x03\n\x0eSpeedTestStats\x12!\n\nlatency_ms\x18\x03 \x01(\x02\x42\x02\x18\x01R\tlatencyMs\x12!\n\nstart_time\x18\x04 \x01(\x04\x42\x02\x18\x01R\tstartTime\x12*\n\x11upload_start_time\x18\x05 \x01(\x03R\x0fuploadStartTime\x12.\n\x13\x64ownload_start_time\x18\x06 \x01(\x03R\x11\x64ownloadStartTime\x12\x1f\n\x0bupload_mbps\x18\x01 \x01(\x02R\nuploadMbps\x12#\n\rdownload_mbps\x18\x02 \x01(\x02R\x0c\x64ownloadMbps\x12@\n\x06target\x18\x07 \x01(\x0e\x32(.SpaceX.API.Device.SpeedTestStats.TargetR\x06target\x12\x1f\n\x0btcp_streams\x18\x08 \x01(\rR\ntcpStreams\"2\n\x06Target\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x46\x41STCOM\x10\x01\x12\x0e\n\nCLOUDFLARE\x10\x02\"\xda\x01\n\x0e\x43lientPlatform\x12\x46\n\x08platform\x18\x01 \x01(\x0e\x32*.SpaceX.API.Device.ClientPlatform.PlatformR\x08platform\x12#\n\rmajor_version\x18\x02 \x01(\x02R\x0cmajorVersion\x12#\n\rminor_version\x18\x03 \x01(\x02R\x0cminorVersion\"6\n\x08Platform\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03IOS\x10\x01\x12\x0b\n\x07\x41NDROID\x10\x02\x12\x07\n\x03WEB\x10\x03\"\xdd\x01\n\x10SpeedTestRequest\x12\x0e\n\x02id\x18\x04 \x01(\rR\x02id\x12L\n\x10\x63lient_speedtest\x18\x01 \x01(\x0b\x32!.SpaceX.API.Device.SpeedTestStatsR\x0f\x63lientSpeedtest\x12\x1f\n\x0b\x63lient_rssi\x18\x02 \x01(\x02R\nclientRssi\x12J\n\x0f\x63lient_platform\x18\x03 \x01(\x0b\x32!.SpaceX.API.Device.ClientPlatformR\x0e\x63lientPlatform\"\xf5\x05\n\x11SpeedTestResponse\x12%\n\x0c\x64ownload_bps\x18\x01 \x01(\x02\x42\x02\x18\x01R\x0b\x64ownloadBps\x12!\n\nupload_bps\x18\x02 \x01(\x02\x42\x02\x18\x01R\tuploadBps\x12\x1f\n\tlatency_s\x18\x03 \x01(\x02\x42\x02\x18\x01R\x08latencyS\x12\'\n\rdownload_mbps\x18\x04 \x01(\x02\x42\x02\x18\x01R\x0c\x64ownloadMbps\x12#\n\x0bupload_mbps\x18\x05 \x01(\x02\x42\x02\x18\x01R\nuploadMbps\x12!\n\nlatency_ms\x18\x06 \x01(\x02\x42\x02\x18\x01R\tlatencyMs\x12L\n\x10router_speedtest\x18\x0f \x01(\x0b\x32!.SpaceX.API.Device.SpeedTestStatsR\x0frouterSpeedtest\x12\x36\n\x18\x64ownload_mbps_1_tcp_conn\x18\x07 \x01(\x02R\x14\x64ownloadMbps1TcpConn\x12\x32\n\x16upload_mbps_1_tcp_conn\x18\x08 \x01(\x02R\x12uploadMbps1TcpConn\x12\x36\n\x18\x64ownload_mbps_4_tcp_conn\x18\t \x01(\x02R\x14\x64ownloadMbps4TcpConn\x12\x32\n\x16upload_mbps_4_tcp_conn\x18\n \x01(\x02R\x12uploadMbps4TcpConn\x12\x38\n\x19\x64ownload_mbps_16_tcp_conn\x18\x0b \x01(\x02R\x15\x64ownloadMbps16TcpConn\x12\x34\n\x17upload_mbps_16_tcp_conn\x18\x0c \x01(\x02R\x13uploadMbps16TcpConn\x12\x38\n\x19\x64ownload_mbps_64_tcp_conn\x18\r \x01(\x02R\x15\x64ownloadMbps64TcpConn\x12\x34\n\x17upload_mbps_64_tcp_conn\x18\x0e \x01(\x02R\x13uploadMbps64TcpConn\"6\n\x15RunIperfServerRequest\x12\x1d\n\nduration_s\x18\x01 \x01(\rR\tdurationS\",\n\x16RunIperfServerResponse\x12\x12\n\x04port\x18\x01 \x01(\rR\x04port\"\x17\n\x15GetConnectionsRequest\"\xca\x02\n\x16GetConnectionsResponse\x12S\n\x08services\x18\x01 \x03(\x0b\x32\x37.SpaceX.API.Device.GetConnectionsResponse.ServicesEntryR\x08services\x1ax\n\rServicesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12Q\n\x05value\x18\x02 \x01(\x0b\x32;.SpaceX.API.Device.GetConnectionsResponse.ServiceConnectionR\x05value:\x02\x38\x01\x1a\x61\n\x11ServiceConnection\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x32\n\x15seconds_since_success\x18\x02 \x01(\x05R\x13secondsSinceSuccess\"\x16\n\x14GetDeviceInfoRequest\"W\n\x15GetDeviceInfoResponse\x12>\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.DeviceInfoR\ndeviceInfo\"I\n\x15SetTrustedKeysRequest\x12\x30\n\x04keys\x18\x01 \x03(\x0b\x32\x1c.SpaceX.API.Device.PublicKeyR\x04keys\"\x18\n\x16SetTrustedKeysResponse\"\xca\x01\n\rSetSkuRequest\x12\x10\n\x03sku\x18\x01 \x01(\tR\x03sku\x12!\n\x0c\x63ountry_code\x18\x02 \x01(\tR\x0b\x63ountryCode\x12,\n\x12\x61pply_country_code\x18\x04 \x01(\x08R\x10\x61pplyCountryCode\x12(\n\x10pin_country_code\x18\x05 \x01(\x08R\x0epinCountryCode\x12,\n\x12\x63ustom_power_table\x18\x06 \x01(\x08R\x10\x63ustomPowerTable\"\x10\n\x0eSetSkuResponse\"\x0f\n\rUpdateRequest\"\x10\n\x0eUpdateResponse\"\x17\n\x15RestartControlRequest\"\x18\n\x16RestartControlResponse\"\x1d\n\x1bGetNetworkInterfacesRequest\"s\n\x1cGetNetworkInterfacesResponse\x12S\n\x12network_interfaces\x18\xee\x07 \x03(\x0b\x32#.SpaceX.API.Device.NetworkInterfaceR\x11networkInterfaces\"\x16\n\x14GetRadioStatsRequest\"W\n\x15GetRadioStatsResponse\x12>\n\x0bradio_stats\x18\x01 \x03(\x0b\x32\x1d.SpaceX.API.Device.RadioStatsR\nradioStats\"\x14\n\x12GetHeapDumpRequest\"2\n\x13GetHeapDumpResponse\x12\x1b\n\theap_dump\x18\x01 \x01(\tR\x08heapDump\"O\n\x12GetLocationRequest\x12\x39\n\x06source\x18\x01 \x01(\x0e\x32!.SpaceX.API.Device.PositionSourceR\x06source\"\xa7\x01\n\x13GetLocationResponse\x12\x30\n\x03lla\x18\x01 \x01(\x0b\x32\x1e.SpaceX.API.Device.LLAPositionR\x03lla\x12\x17\n\x07sigma_m\x18\x04 \x01(\x01R\x06sigmaM\x12\x39\n\x06source\x18\x03 \x01(\x0e\x32!.SpaceX.API.Device.PositionSourceR\x06sourceJ\x04\x08\x02\x10\x03R\x04\x65\x63\x65\x66\"\xa5\x08\n\x11\x44ishSetEmcRequest\x12\x14\n\x05theta\x18\x01 \x01(\x01R\x05theta\x12\x10\n\x03phi\x18\x02 \x01(\x01R\x03phi\x12\x17\n\x07rx_chan\x18\x03 \x01(\rR\x06rxChan\x12\x17\n\x07tx_chan\x18\x04 \x01(\rR\x06txChan\x12\x1e\n\nmodulation\x18\x05 \x01(\rR\nmodulation\x12,\n\x12\x64\x65sired_tilt_angle\x18\x07 \x01(\x01R\x10\x64\x65siredTiltAngle\x12#\n\rchan_override\x18\x08 \x01(\x08R\x0c\x63hanOverride\x12#\n\rtheta_enabled\x18\t \x01(\x08R\x0cthetaEnabled\x12\x1f\n\x0bphi_enabled\x18\n \x01(\x08R\nphiEnabled\x12\x12\n\x04idle\x18\x0b \x01(\x08R\x04idle\x12%\n\x0e\x66\x61st_switching\x18\x0c \x01(\x08R\rfastSwitching\x12\x1d\n\nsky_search\x18\r \x01(\x08R\tskySearch\x12(\n\x10\x66orce_pll_unlock\x18\x0e \x01(\x08R\x0e\x66orcePllUnlock\x12,\n\x12\x66orce_eirp_failure\x18\x0f \x01(\x08R\x10\x66orceEirpFailure\x12\x30\n\x14snow_active_override\x18\x10 \x01(\x08R\x12snowActiveOverride\x12%\n\x0emanual_tilting\x18\x12 \x01(\x08R\rmanualTilting\x12$\n\x0etilt_to_stowed\x18\x13 \x01(\x08R\x0ctiltToStowed\x12\x16\n\x06reboot\x18\x14 \x01(\x08R\x06reboot\x12\x32\n\x15\x63ontinuous_motor_test\x18\x15 \x01(\x08R\x13\x63ontinuousMotorTest\x12\x38\n\x18\x64istance_override_meters\x18\x16 \x01(\x01R\x16\x64istanceOverrideMeters\x12\x38\n\x18\x61mplitude_taper_override\x18\x17 \x01(\rR\x16\x61mplitudeTaperOverride\x12\x32\n\x15\x63ountry_code_override\x18\x18 \x01(\rR\x13\x63ountryCodeOverride\x12\x33\n\x16tx_duty_cycle_override\x18\x19 \x01(\x05R\x13txDutyCycleOverride\x12\x33\n\x16rx_duty_cycle_override\x18\x1a \x01(\x05R\x13rxDutyCycleOverride\x12@\n\x1d\x65irp_legal_limit_dbw_override\x18\x1b \x01(\x01R\x19\x65irpLegalLimitDbwOverride\x12,\n\x12\x65irp_adjustment_db\x18\x1c \x01(\x01R\x10\x65irpAdjustmentDb\"\x14\n\x12\x44ishSetEmcResponse\":\n\x1e\x44ishSetMaxPowerTestModeRequest\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\";\n\x1f\x44ishSetMaxPowerTestModeResponse\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\"\x13\n\x11\x44ishGetEmcRequest\"\x8f\x13\n\x12\x44ishGetEmcResponse\x12\x12\n\x04uuid\x18\x02 \x01(\tR\x04uuid\x12\x1c\n\ttimestamp\x18\x03 \x01(\x04R\ttimestamp\x12%\n\x0e\x63plane_updates\x18\x0b \x01(\rR\rcplaneUpdates\x12!\n\x0cgps_latitude\x18\x10 \x01(\x01R\x0bgpsLatitude\x12#\n\rgps_longitude\x18\x11 \x01(\x01R\x0cgpsLongitude\x12\x19\n\x08gps_pdop\x18\x12 \x01(\x01R\x07gpsPdop\x12\x17\n\x07rf_mode\x18\x13 \x01(\rR\x06rfMode\x12\x10\n\x03phi\x18\x14 \x01(\x01R\x03phi\x12\x14\n\x05theta\x18\x15 \x01(\x01R\x05theta\x12\x1d\n\nrx_channel\x18\x16 \x01(\rR\trxChannel\x12\x1d\n\ntx_channel\x18\x17 \x01(\rR\ttxChannel\x12\x1a\n\tt_dbf_max\x18\x18 \x01(\x02R\x07tDbfMax\x12\x19\n\x08t_center\x18\x19 \x01(\x01R\x07tCenter\x12>\n\x1c\x61uto_power_snow_melt_enabled\x18\x1e \x01(\x08R\x18\x61utoPowerSnowMeltEnabled\x12\x18\n\x07voltage\x18  \x01(\x01R\x07voltage\x12\"\n\rrx_beam_state\x18! \x01(\rR\x0brxBeamState\x12\"\n\rtx_beam_state\x18\" \x01(\rR\x0btxBeamState\x12*\n\x11half_duplex_state\x18# \x01(\rR\x0fhalfDuplexState\x12.\n\x13manual_tilt_enabled\x18$ \x01(\x08R\x11manualTiltEnabled\x12\x1d\n\ntilt_angle\x18% \x01(\x01R\ttiltAngle\x12/\n\x14pll_tx_lock_detected\x18& \x01(\rR\x11pllTxLockDetected\x12\x36\n\x17\x65irp_exceeded_threshold\x18\' \x01(\x08R\x15\x65irpExceededThreshold\x12\x32\n\x15idle_override_enabled\x18) \x01(\x08R\x13idleOverrideEnabled\x12\x34\n\x16theta_override_enabled\x18* \x01(\x08R\x14thetaOverrideEnabled\x12\x30\n\x14theta_override_value\x18+ \x01(\x01R\x12thetaOverrideValue\x12\x30\n\x14phi_override_enabled\x18, \x01(\x08R\x12phiOverrideEnabled\x12,\n\x12phi_override_value\x18- \x01(\x01R\x10phiOverrideValue\x12\x33\n\x16rx_chan_override_value\x18. \x01(\rR\x13rxChanOverrideValue\x12\x33\n\x16tx_chan_override_value\x18/ \x01(\rR\x13txChanOverrideValue\x12=\n\x1bsky_search_override_enabled\x18\x30 \x01(\x08R\x18skySearchOverrideEnabled\x12\x34\n\x16\x66\x61st_switching_enabled\x18\x31 \x01(\x08R\x14\x66\x61stSwitchingEnabled\x12:\n\x19modulation_override_value\x18\x32 \x01(\rR\x17modulationOverrideValue\x12,\n\x12\x66orce_eirp_failure\x18\x33 \x01(\x08R\x10\x66orceEirpFailure\x12(\n\x10\x66orce_pll_unlock\x18\x34 \x01(\x08R\x0e\x66orcePllUnlock\x12$\n\x0eut_ine_success\x18\x35 \x01(\rR\x0cutIneSuccess\x12\x19\n\x08rf_ready\x18\x36 \x01(\x08R\x07rfReady\x12$\n\x0etilt_to_stowed\x18\x37 \x01(\x08R\x0ctiltToStowed\x12\x16\n\x06reboot\x18\x38 \x01(\x08R\x06reboot\x12\x32\n\x15\x63ontinuous_motor_test\x18\x39 \x01(\x08R\x13\x63ontinuousMotorTest\x12\x38\n\x18\x64istance_override_meters\x18: \x01(\x01R\x16\x64istanceOverrideMeters\x12\x38\n\x18\x61mplitude_taper_override\x18; \x01(\rR\x16\x61mplitudeTaperOverride\x12\x36\n\x17\x61mplitude_taper_enabled\x18< \x01(\x08R\x15\x61mplitudeTaperEnabled\x12\x32\n\x15\x61mplitude_taper_scale\x18= \x01(\x01R\x13\x61mplitudeTaperScale\x12\x32\n\x15\x63ountry_code_override\x18> \x01(\rR\x13\x63ountryCodeOverride\x12\x32\n\x15max_pointing_distance\x18? \x01(\x01R\x13maxPointingDistance\x12\x36\n\x17\x64istance_scaling_factor\x18@ \x01(\x01R\x15\x64istanceScalingFactor\x12\x33\n\x16tx_duty_cycle_override\x18\x41 \x01(\x05R\x13txDutyCycleOverride\x12\x33\n\x16rx_duty_cycle_override\x18\x42 \x01(\x05R\x13rxDutyCycleOverride\x12\x1c\n\ntx_time_ms\x18\x43 \x01(\x02R\x08txTimeMs\x12\x1c\n\nrx_time_ms\x18\x44 \x01(\x02R\x08rxTimeMs\x12/\n\x14\x65irp_legal_limit_dbw\x18\x45 \x01(\x01R\x11\x65irpLegalLimitDbw\x12@\n\x1d\x65irp_legal_limit_dbw_override\x18\x46 \x01(\x01R\x19\x65irpLegalLimitDbwOverride\x12,\n\x12\x65irp_adjustment_db\x18G \x01(\x01R\x10\x65irpAdjustmentDb\x12,\n\x12\x65irp_predicted_dbw\x18H \x01(\x01R\x10\x65irpPredictedDbwJ\x04\x08\x1a\x10\x1eJ\x04\x08(\x10)R\x10\x62\x61seline_heatingR\x12\x61\x64\x64itional_heatingR\rtotal_heatingR\x14target_total_heatingR\x13\x65irp_scale_override\"\x1b\n\x19GetPersistentStatsRequest\"\x17\n\x15StartSpeedtestRequest\"\x18\n\x16StartSpeedtestResponse\"\xaa\x02\n\x0fSpeedtestStatus\x12\x18\n\x07running\x18\x01 \x01(\x08R\x07running\x12\x0e\n\x02id\x18\x02 \x01(\rR\x02id\x12=\n\x02up\x18\xe8\x07 \x01(\x0b\x32,.SpaceX.API.Device.SpeedtestStatus.DirectionR\x02up\x12\x41\n\x04\x64own\x18\xe9\x07 \x01(\x0b\x32,.SpaceX.API.Device.SpeedtestStatus.DirectionR\x04\x64own\x1ak\n\tDirection\x12)\n\x10throughputs_mbps\x18\x01 \x03(\x02R\x0fthroughputsMbps\x12\x33\n\x03\x65rr\x18\x02 \x01(\x0e\x32!.SpaceX.API.Device.SpeedtestErrorR\x03\x65rr\"\x1b\n\x19GetSpeedtestStatusRequest\"X\n\x1aGetSpeedtestStatusResponse\x12:\n\x06status\x18\x01 \x01(\x0b\x32\".SpaceX.API.Device.SpeedtestStatusR\x06status\"\xf1\x02\n\x1cReportClientSpeedtestRequest\x12\x0e\n\x02id\x18\x01 \x01(\rR\x02id\x12L\n\x10\x63lient_speedtest\x18\x02 \x01(\x0b\x32!.SpaceX.API.Device.SpeedTestStatsR\x0f\x63lientSpeedtest\x12H\n\x0ewifi_speedtest\x18\x05 \x01(\x0b\x32!.SpaceX.API.Device.SpeedTestStatsR\rwifiSpeedtest\x12\x1f\n\x0b\x63lient_rssi\x18\x03 \x01(\x02R\nclientRssi\x12J\n\x0f\x63lient_platform\x18\x04 \x01(\x0b\x32!.SpaceX.API.Device.ClientPlatformR\x0e\x63lientPlatform\x12\x1f\n\x0b\x61pp_version\x18\x06 \x01(\tR\nappVersion\x12\x1b\n\tapp_build\x18\x07 \x01(\rR\x08\x61ppBuild\"\x1f\n\x1dReportClientSpeedtestResponse\"\xba\x01\n\x14\x44ishPowerSaveRequest\x12\x37\n\x18power_save_start_minutes\x18\x01 \x01(\rR\x15powerSaveStartMinutes\x12=\n\x1bpower_save_duration_minutes\x18\x02 \x01(\rR\x18powerSaveDurationMinutes\x12*\n\x11\x65nable_power_save\x18\x03 \x01(\x08R\x0f\x65nablePowerSave\"\x12\n\x10IQCaptureRequest\"\x17\n\x15GetDiagnosticsRequest\"\x92\x03\n\x1aWifiGetDiagnosticsResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12)\n\x10hardware_version\x18\x02 \x01(\tR\x0fhardwareVersion\x12)\n\x10software_version\x18\x03 \x01(\tR\x0fsoftwareVersion\x12Q\n\x08networks\x18\x04 \x03(\x0b\x32\x35.SpaceX.API.Device.WifiGetDiagnosticsResponse.NetworkR\x08networks\x1a\xba\x01\n\x07Network\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x12\n\x04ipv4\x18\x02 \x01(\tR\x04ipv4\x12\x12\n\x04ipv6\x18\x03 \x03(\tR\x04ipv6\x12)\n\x10\x63lients_ethernet\x18\n \x01(\rR\x0f\x63lientsEthernet\x12!\n\x0c\x63lients_2ghz\x18\x0b \x01(\rR\x0b\x63lients2ghz\x12!\n\x0c\x63lients_5ghz\x18\x0c \x01(\rR\x0b\x63lients5ghz\"\xc0\x0b\n\x1a\x44ishGetDiagnosticsResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12)\n\x10hardware_version\x18\x02 \x01(\tR\x0fhardwareVersion\x12)\n\x10software_version\x18\x03 \x01(\tR\x0fsoftwareVersion\x12 \n\x0cutc_offset_s\x18\x04 \x01(\x05R\nutcOffsetS\x12\x66\n\x12hardware_self_test\x18\x07 \x01(\x0e\x32\x38.SpaceX.API.Device.DishGetDiagnosticsResponse.TestResultR\x10hardwareSelfTest\x12L\n\x06\x61lerts\x18\x05 \x01(\x0b\x32\x34.SpaceX.API.Device.DishGetDiagnosticsResponse.AlertsR\x06\x61lerts\x12h\n\x10\x64isablement_code\x18\x06 \x01(\x0e\x32=.SpaceX.API.Device.DishGetDiagnosticsResponse.DisablementCodeR\x0f\x64isablementCode\x12R\n\x08location\x18\x08 \x01(\x0b\x32\x36.SpaceX.API.Device.DishGetDiagnosticsResponse.LocationR\x08location\x1a\xfb\x03\n\x06\x41lerts\x12&\n\x0f\x64ish_is_heating\x18\x01 \x01(\x08R\rdishIsHeating\x12\x32\n\x15\x64ish_thermal_throttle\x18\x02 \x01(\x08R\x13\x64ishThermalThrottle\x12\x32\n\x15\x64ish_thermal_shutdown\x18\x03 \x01(\x08R\x13\x64ishThermalShutdown\x12\x41\n\x1dpower_supply_thermal_throttle\x18\x04 \x01(\x08R\x1apowerSupplyThermalThrottle\x12!\n\x0cmotors_stuck\x18\x05 \x01(\x08R\x0bmotorsStuck\x12\x33\n\x16mast_not_near_vertical\x18\x06 \x01(\x08R\x13mastNotNearVertical\x12\x30\n\x14slow_ethernet_speeds\x18\x07 \x01(\x08R\x12slowEthernetSpeeds\x12\x38\n\x18software_install_pending\x18\x08 \x01(\x08R\x16softwareInstallPending\x12:\n\x1amoving_too_fast_for_policy\x18\t \x01(\x08R\x16movingTooFastForPolicy\x12\x1e\n\nobstructed\x18\n \x01(\x08R\nobstructed\x1a\x87\x01\n\x08Location\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x12\x1a\n\x08latitude\x18\x02 \x01(\x01R\x08latitude\x12\x1c\n\tlongitude\x18\x03 \x01(\x01R\tlongitude\x12\'\n\x0f\x61ltitude_meters\x18\x04 \x01(\x01R\x0e\x61ltitudeMeters\"3\n\nTestResult\x12\r\n\tNO_RESULT\x10\x00\x12\n\n\x06PASSED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"\xe8\x01\n\x0f\x44isablementCode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04OKAY\x10\x01\x12\x15\n\x11NO_ACTIVE_ACCOUNT\x10\x02\x12 \n\x1cTOO_FAR_FROM_SERVICE_ADDRESS\x10\x03\x12\x0c\n\x08IN_OCEAN\x10\x04\x12\x13\n\x0fINVALID_COUNTRY\x10\x05\x12\x13\n\x0f\x42LOCKED_COUNTRY\x10\x06\x12\x1f\n\x1b\x44\x41TA_OVERAGE_SANDBOX_POLICY\x10\x07\x12\x14\n\x10\x43\x45LL_IS_DISABLED\x10\x08\x12\x16\n\x12UNLICENSED_COUNTRY\x10\t\"H\n\x1aTcpConnectivityTestRequest\x12\x16\n\x06target\x18\x01 \x01(\tR\x06target\x12\x12\n\x04port\x18\x02 \x01(\rR\x04port\"\xb3\x04\n\x1aUdpConnectivityTestRequest\x12\x16\n\x06target\x18\x01 \x01(\tR\x06target\x12\x12\n\x04port\x18\x02 \x01(\rR\x04port\x12]\n\nprobe_data\x18\x03 \x01(\x0e\x32>.SpaceX.API.Device.UdpConnectivityTestRequest.UDPProbeDataTypeR\tprobeData\"\x89\x03\n\x10UDPProbeDataType\x12\t\n\x05\x45MPTY\x10\x00\x12\x16\n\x12\x44NS_STATUS_REQUEST\x10\x01\x12\x15\n\x11\x44TLS_CLIENT_HELLO\x10\x02\x12\x18\n\x14\x44NS_VERSION_BIND_REQ\x10\x03\x12\r\n\tRPC_CHECK\x10\x04\x12\n\n\x06\x44NS_SD\x10\x05\x12\x12\n\x0eSNMP_V1_PUBLIC\x10\x06\x12\x17\n\x13SNMP_V3_GET_REQUEST\x10\x07\x12\x0f\n\x0bNTP_MESSAGE\x10\x08\x12\t\n\x05XDMCP\x10\t\x12\x0c\n\x08KERBEROS\x10\n\x12\x0f\n\x0bSIP_OPTIONS\x10\x0b\x12\x13\n\x0fLDAP_SEARCH_REQ\x10\x0c\x12\x13\n\x0fMEMCACHED_STATS\x10\r\x12\x0b\n\x07OPENVPN\x10\x0e\x12\x0e\n\nCIFS_NS_UC\x10\x0f\x12\x0c\n\x08TFTP_GET\x10\x10\x12\x0f\n\x0b\x44HCP_INFORM\x10\x11\x12\x08\n\x04QUIC\x10\x12\x12\t\n\x05RIPV1\x10\x13\x12\x11\n\rNFS_PROC_NULL\x10\x14\x12\x10\n\x0c\x43OAP_REQUEST\x10\x15*\x8c\x01\n\x0ePositionSource\x12\x08\n\x04\x41UTO\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x0b\n\x07UT_INFO\x10\x02\x12\x0c\n\x08\x45XTERNAL\x10\x03\x12\x07\n\x03GPS\x10\x04\x12\x0c\n\x08STARLINK\x10\x05\x12\x0b\n\x07GNC_GPS\x10\x06\x12\x0b\n\x07GNC_PNT\x10\x07\x12\r\n\tGNC_FUSED\x10\x08\x12\x0b\n\x07GNC_RAW\x10\t*\xb7\x01\n\x0eSpeedtestError\x12\x18\n\x14SPEEDTEST_ERROR_NONE\x10\x00\x12\x1b\n\x17SPEEDTEST_ERROR_UNKNOWN\x10\x01\x12\x19\n\x15SPEEDTEST_ERROR_TOKEN\x10\x02\x12\x17\n\x13SPEEDTEST_ERROR_API\x10\x03\x12\x1d\n\x19SPEEDTEST_ERROR_NO_RESULT\x10\x04\x12\x1b\n\x17SPEEDTEST_ERROR_OFFLINE\x10\x05\x32\x95\x01\n\x06\x44\x65vice\x12H\n\x06Stream\x12\x1b.SpaceX.API.Device.ToDevice\x1a\x1d.SpaceX.API.Device.FromDevice(\x01\x30\x01\x12\x41\n\x06Handle\x12\x1a.SpaceX.API.Device.Request\x1a\x1b.SpaceX.API.Device.ResponseB\xd5\x01\n\x15\x63om.SpaceX.API.DeviceB\x0b\x44\x65viceProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.device_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\013DeviceProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_REQUEST'].fields_by_name['initiate_remote_ssh']._loaded_options = None
  _globals['_REQUEST'].fields_by_name['initiate_remote_ssh']._serialized_options = b'\030\001'
  _globals['_REQUEST'].fields_by_name['wifi_set_mesh_config']._loaded_options = None
  _globals['_REQUEST'].fields_by_name['wifi_set_mesh_config']._serialized_options = b'\030\001'
  _globals['_RESPONSE'].fields_by_name['initiate_remote_ssh']._loaded_options = None
  _globals['_RESPONSE'].fields_by_name['initiate_remote_ssh']._serialized_options = b'\030\001'
  _globals['_RESPONSE'].fields_by_name['wifi_set_mesh_config']._loaded_options = None
  _globals['_RESPONSE'].fields_by_name['wifi_set_mesh_config']._serialized_options = b'\030\001'
  _globals['_GETLOGRESPONSE'].fields_by_name['syslog']._loaded_options = None
  _globals['_GETLOGRESPONSE'].fields_by_name['syslog']._serialized_options = b'\030\001'
  _globals['_GETLOGRESPONSE'].fields_by_name['offline_log']._loaded_options = None
  _globals['_GETLOGRESPONSE'].fields_by_name['offline_log']._serialized_options = b'\030\001'
  _globals['_GETLOGRESPONSE'].fields_by_name['persistent_log']._loaded_options = None
  _globals['_GETLOGRESPONSE'].fields_by_name['persistent_log']._serialized_options = b'\030\001'
  _globals['_GETPINGRESPONSE_RESULTSENTRY']._loaded_options = None
  _globals['_GETPINGRESPONSE_RESULTSENTRY']._serialized_options = b'8\001'
  _globals['_SPEEDTESTSTATS'].fields_by_name['latency_ms']._loaded_options = None
  _globals['_SPEEDTESTSTATS'].fields_by_name['latency_ms']._serialized_options = b'\030\001'
  _globals['_SPEEDTESTSTATS'].fields_by_name['start_time']._loaded_options = None
  _globals['_SPEEDTESTSTATS'].fields_by_name['start_time']._serialized_options = b'\030\001'
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['download_bps']._loaded_options = None
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['download_bps']._serialized_options = b'\030\001'
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['upload_bps']._loaded_options = None
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['upload_bps']._serialized_options = b'\030\001'
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['latency_s']._loaded_options = None
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['latency_s']._serialized_options = b'\030\001'
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['download_mbps']._loaded_options = None
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['download_mbps']._serialized_options = b'\030\001'
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['upload_mbps']._loaded_options = None
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['upload_mbps']._serialized_options = b'\030\001'
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['latency_ms']._loaded_options = None
  _globals['_SPEEDTESTRESPONSE'].fields_by_name['latency_ms']._serialized_options = b'\030\001'
  _globals['_GETCONNECTIONSRESPONSE_SERVICESENTRY']._loaded_options = None
  _globals['_GETCONNECTIONSRESPONSE_SERVICESENTRY']._serialized_options = b'8\001'
  _globals['_POSITIONSOURCE']._serialized_start=26898
  _globals['_POSITIONSOURCE']._serialized_end=27038
  _globals['_SPEEDTESTERROR']._serialized_start=27041
  _globals['_SPEEDTESTERROR']._serialized_end=27224
  _globals['_TODEVICE']._serialized_start=337
  _globals['_TODEVICE']._serialized_end=483
  _globals['_FROMDEVICE']._serialized_start=486
  _globals['_FROMDEVICE']._serialized_end=687
  _globals['_SENSITIVECOMMAND']._serialized_start=690
  _globals['_SENSITIVECOMMAND']._serialized_end=882
  _globals['_HEALTHCHECK']._serialized_start=884
  _globals['_HEALTHCHECK']._serialized_end=897
  _globals['_REQUEST']._serialized_start=900
  _globals['_REQUEST']._serialized_end=8225
  _globals['_RESPONSE']._serialized_start=8228
  _globals['_RESPONSE']._serialized_end=14725
  _globals['_EVENT']._serialized_start=14728
  _globals['_EVENT']._serialized_end=15115
  _globals['_WIFICLOUDSTATUSEVENT']._serialized_start=15118
  _globals['_WIFICLOUDSTATUSEVENT']._serialized_end=15296
  _globals['_ENABLEDEBUGTELEMREQUEST']._serialized_start=15298
  _globals['_ENABLEDEBUGTELEMREQUEST']._serialized_end=15354
  _globals['_ENABLEDEBUGTELEMRESPONSE']._serialized_start=15356
  _globals['_ENABLEDEBUGTELEMRESPONSE']._serialized_end=15382
  _globals['_FACTORYRESETREQUEST']._serialized_start=15384
  _globals['_FACTORYRESETREQUEST']._serialized_end=15405
  _globals['_FACTORYRESETRESPONSE']._serialized_start=15407
  _globals['_FACTORYRESETRESPONSE']._serialized_end=15429
  _globals['_GETTIMEREQUEST']._serialized_start=15431
  _globals['_GETTIMEREQUEST']._serialized_end=15447
  _globals['_GETTIMERESPONSE']._serialized_start=15449
  _globals['_GETTIMERESPONSE']._serialized_end=15495
  _globals['_FUSEREQUEST']._serialized_start=15497
  _globals['_FUSEREQUEST']._serialized_end=15549
  _globals['_FUSERESPONSE']._serialized_start=15551
  _globals['_FUSERESPONSE']._serialized_end=15565
  _globals['_GETHISTORYREQUEST']._serialized_start=15567
  _globals['_GETHISTORYREQUEST']._serialized_end=15586
  _globals['_GETLOGREQUEST']._serialized_start=15588
  _globals['_GETLOGREQUEST']._serialized_end=15603
  _globals['_GETLOGRESPONSE']._serialized_start=15606
  _globals['_GETLOGRESPONSE']._serialized_end=15983
  _globals['_GETLOGRESPONSE_LOGS']._serialized_start=15860
  _globals['_GETLOGRESPONSE_LOGS']._serialized_end=15983
  _globals['_GETPINGREQUEST']._serialized_start=15985
  _globals['_GETPINGREQUEST']._serialized_end=16001
  _globals['_GETPINGRESPONSE']._serialized_start=16004
  _globals['_GETPINGRESPONSE']._serialized_end=16187
  _globals['_GETPINGRESPONSE_RESULTSENTRY']._serialized_start=16098
  _globals['_GETPINGRESPONSE_RESULTSENTRY']._serialized_end=16187
  _globals['_PINGHOSTREQUEST']._serialized_start=16189
  _globals['_PINGHOSTREQUEST']._serialized_end=16252
  _globals['_PINGHOSTRESPONSE']._serialized_start=16254
  _globals['_PINGHOSTRESPONSE']._serialized_end=16327
  _globals['_GETSTATUSREQUEST']._serialized_start=16329
  _globals['_GETSTATUSREQUEST']._serialized_end=16347
  _globals['_REBOOTREQUEST']._serialized_start=16349
  _globals['_REBOOTREQUEST']._serialized_end=16364
  _globals['_REBOOTRESPONSE']._serialized_start=16366
  _globals['_REBOOTRESPONSE']._serialized_end=16382
  _globals['_SPEEDTESTSTATS']._serialized_start=16385
  _globals['_SPEEDTESTSTATS']._serialized_end=16784
  _globals['_SPEEDTESTSTATS_TARGET']._serialized_start=16734
  _globals['_SPEEDTESTSTATS_TARGET']._serialized_end=16784
  _globals['_CLIENTPLATFORM']._serialized_start=16787
  _globals['_CLIENTPLATFORM']._serialized_end=17005
  _globals['_CLIENTPLATFORM_PLATFORM']._serialized_start=16951
  _globals['_CLIENTPLATFORM_PLATFORM']._serialized_end=17005
  _globals['_SPEEDTESTREQUEST']._serialized_start=17008
  _globals['_SPEEDTESTREQUEST']._serialized_end=17229
  _globals['_SPEEDTESTRESPONSE']._serialized_start=17232
  _globals['_SPEEDTESTRESPONSE']._serialized_end=17989
  _globals['_RUNIPERFSERVERREQUEST']._serialized_start=17991
  _globals['_RUNIPERFSERVERREQUEST']._serialized_end=18045
  _globals['_RUNIPERFSERVERRESPONSE']._serialized_start=18047
  _globals['_RUNIPERFSERVERRESPONSE']._serialized_end=18091
  _globals['_GETCONNECTIONSREQUEST']._serialized_start=18093
  _globals['_GETCONNECTIONSREQUEST']._serialized_end=18116
  _globals['_GETCONNECTIONSRESPONSE']._serialized_start=18119
  _globals['_GETCONNECTIONSRESPONSE']._serialized_end=18449
  _globals['_GETCONNECTIONSRESPONSE_SERVICESENTRY']._serialized_start=18230
  _globals['_GETCONNECTIONSRESPONSE_SERVICESENTRY']._serialized_end=18350
  _globals['_GETCONNECTIONSRESPONSE_SERVICECONNECTION']._serialized_start=18352
  _globals['_GETCONNECTIONSRESPONSE_SERVICECONNECTION']._serialized_end=18449
  _globals['_GETDEVICEINFOREQUEST']._serialized_start=18451
  _globals['_GETDEVICEINFOREQUEST']._serialized_end=18473
  _globals['_GETDEVICEINFORESPONSE']._serialized_start=18475
  _globals['_GETDEVICEINFORESPONSE']._serialized_end=18562
  _globals['_SETTRUSTEDKEYSREQUEST']._serialized_start=18564
  _globals['_SETTRUSTEDKEYSREQUEST']._serialized_end=18637
  _globals['_SETTRUSTEDKEYSRESPONSE']._serialized_start=18639
  _globals['_SETTRUSTEDKEYSRESPONSE']._serialized_end=18663
  _globals['_SETSKUREQUEST']._serialized_start=18666
  _globals['_SETSKUREQUEST']._serialized_end=18868
  _globals['_SETSKURESPONSE']._serialized_start=18870
  _globals['_SETSKURESPONSE']._serialized_end=18886
  _globals['_UPDATEREQUEST']._serialized_start=18888
  _globals['_UPDATEREQUEST']._serialized_end=18903
  _globals['_UPDATERESPONSE']._serialized_start=18905
  _globals['_UPDATERESPONSE']._serialized_end=18921
  _globals['_RESTARTCONTROLREQUEST']._serialized_start=18923
  _globals['_RESTARTCONTROLREQUEST']._serialized_end=18946
  _globals['_RESTARTCONTROLRESPONSE']._serialized_start=18948
  _globals['_RESTARTCONTROLRESPONSE']._serialized_end=18972
  _globals['_GETNETWORKINTERFACESREQUEST']._serialized_start=18974
  _globals['_GETNETWORKINTERFACESREQUEST']._serialized_end=19003
  _globals['_GETNETWORKINTERFACESRESPONSE']._serialized_start=19005
  _globals['_GETNETWORKINTERFACESRESPONSE']._serialized_end=19120
  _globals['_GETRADIOSTATSREQUEST']._serialized_start=19122
  _globals['_GETRADIOSTATSREQUEST']._serialized_end=19144
  _globals['_GETRADIOSTATSRESPONSE']._serialized_start=19146
  _globals['_GETRADIOSTATSRESPONSE']._serialized_end=19233
  _globals['_GETHEAPDUMPREQUEST']._serialized_start=19235
  _globals['_GETHEAPDUMPREQUEST']._serialized_end=19255
  _globals['_GETHEAPDUMPRESPONSE']._serialized_start=19257
  _globals['_GETHEAPDUMPRESPONSE']._serialized_end=19307
  _globals['_GETLOCATIONREQUEST']._serialized_start=19309
  _globals['_GETLOCATIONREQUEST']._serialized_end=19388
  _globals['_GETLOCATIONRESPONSE']._serialized_start=19391
  _globals['_GETLOCATIONRESPONSE']._serialized_end=19558
  _globals['_DISHSETEMCREQUEST']._serialized_start=19561
  _globals['_DISHSETEMCREQUEST']._serialized_end=20622
  _globals['_DISHSETEMCRESPONSE']._serialized_start=20624
  _globals['_DISHSETEMCRESPONSE']._serialized_end=20644
  _globals['_DISHSETMAXPOWERTESTMODEREQUEST']._serialized_start=20646
  _globals['_DISHSETMAXPOWERTESTMODEREQUEST']._serialized_end=20704
  _globals['_DISHSETMAXPOWERTESTMODERESPONSE']._serialized_start=20706
  _globals['_DISHSETMAXPOWERTESTMODERESPONSE']._serialized_end=20765
  _globals['_DISHGETEMCREQUEST']._serialized_start=20767
  _globals['_DISHGETEMCREQUEST']._serialized_end=20786
  _globals['_DISHGETEMCRESPONSE']._serialized_start=20789
  _globals['_DISHGETEMCRESPONSE']._serialized_end=23236
  _globals['_GETPERSISTENTSTATSREQUEST']._serialized_start=23238
  _globals['_GETPERSISTENTSTATSREQUEST']._serialized_end=23265
  _globals['_STARTSPEEDTESTREQUEST']._serialized_start=23267
  _globals['_STARTSPEEDTESTREQUEST']._serialized_end=23290
  _globals['_STARTSPEEDTESTRESPONSE']._serialized_start=23292
  _globals['_STARTSPEEDTESTRESPONSE']._serialized_end=23316
  _globals['_SPEEDTESTSTATUS']._serialized_start=23319
  _globals['_SPEEDTESTSTATUS']._serialized_end=23617
  _globals['_SPEEDTESTSTATUS_DIRECTION']._serialized_start=23510
  _globals['_SPEEDTESTSTATUS_DIRECTION']._serialized_end=23617
  _globals['_GETSPEEDTESTSTATUSREQUEST']._serialized_start=23619
  _globals['_GETSPEEDTESTSTATUSREQUEST']._serialized_end=23646
  _globals['_GETSPEEDTESTSTATUSRESPONSE']._serialized_start=23648
  _globals['_GETSPEEDTESTSTATUSRESPONSE']._serialized_end=23736
  _globals['_REPORTCLIENTSPEEDTESTREQUEST']._serialized_start=23739
  _globals['_REPORTCLIENTSPEEDTESTREQUEST']._serialized_end=24108
  _globals['_REPORTCLIENTSPEEDTESTRESPONSE']._serialized_start=24110
  _globals['_REPORTCLIENTSPEEDTESTRESPONSE']._serialized_end=24141
  _globals['_DISHPOWERSAVEREQUEST']._serialized_start=24144
  _globals['_DISHPOWERSAVEREQUEST']._serialized_end=24330
  _globals['_IQCAPTUREREQUEST']._serialized_start=24332
  _globals['_IQCAPTUREREQUEST']._serialized_end=24350
  _globals['_GETDIAGNOSTICSREQUEST']._serialized_start=24352
  _globals['_GETDIAGNOSTICSREQUEST']._serialized_end=24375
  _globals['_WIFIGETDIAGNOSTICSRESPONSE']._serialized_start=24378
  _globals['_WIFIGETDIAGNOSTICSRESPONSE']._serialized_end=24780
  _globals['_WIFIGETDIAGNOSTICSRESPONSE_NETWORK']._serialized_start=24594
  _globals['_WIFIGETDIAGNOSTICSRESPONSE_NETWORK']._serialized_end=24780
  _globals['_DISHGETDIAGNOSTICSRESPONSE']._serialized_start=24783
  _globals['_DISHGETDIAGNOSTICSRESPONSE']._serialized_end=26255
  _globals['_DISHGETDIAGNOSTICSRESPONSE_ALERTS']._serialized_start=25322
  _globals['_DISHGETDIAGNOSTICSRESPONSE_ALERTS']._serialized_end=25829
  _globals['_DISHGETDIAGNOSTICSRESPONSE_LOCATION']._serialized_start=25832
  _globals['_DISHGETDIAGNOSTICSRESPONSE_LOCATION']._serialized_end=25967
  _globals['_DISHGETDIAGNOSTICSRESPONSE_TESTRESULT']._serialized_start=25969
  _globals['_DISHGETDIAGNOSTICSRESPONSE_TESTRESULT']._serialized_end=26020
  _globals['_DISHGETDIAGNOSTICSRESPONSE_DISABLEMENTCODE']._serialized_start=26023
  _globals['_DISHGETDIAGNOSTICSRESPONSE_DISABLEMENTCODE']._serialized_end=26255
  _globals['_TCPCONNECTIVITYTESTREQUEST']._serialized_start=26257
  _globals['_TCPCONNECTIVITYTESTREQUEST']._serialized_end=26329
  _globals['_UDPCONNECTIVITYTESTREQUEST']._serialized_start=26332
  _globals['_UDPCONNECTIVITYTESTREQUEST']._serialized_end=26895
  _globals['_UDPCONNECTIVITYTESTREQUEST_UDPPROBEDATATYPE']._serialized_start=26502
  _globals['_UDPCONNECTIVITYTESTREQUEST_UDPPROBEDATATYPE']._serialized_end=26895
  _globals['_DEVICE']._serialized_start=27227
  _globals['_DEVICE']._serialized_end=27376
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/dish.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/dish.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spacex.api.device import common_pb2 as spacex_dot_api_dot_device_dot_common__pb2
from spacex.api.device import dish_config_pb2 as spacex_dot_api_dot_device_dot_dish__config__pb2
from spacex.api.device import rssi_scan_pb2 as spacex_dot_api_dot_device_dot_rssi__scan__pb2
from spacex.api.satellites.network import ut_disablement_codes_pb2 as spacex_dot_api_dot_satellites_dot_network_dot_ut__disablement__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cspacex/api/device/dish.proto\x12\x11SpaceX.API.Device\x1a\x1espacex/api/device/common.proto\x1a#spacex/api/device/dish_config.proto\x1a!spacex/api/device/rssi_scan.proto\x1a\x38spacex/api/satellites/network/ut_disablement_codes.proto\")\n\x0f\x44ishStowRequest\x12\x16\n\x06unstow\x18\x01 \x01(\x08R\x06unstow\"\x12\n\x10\x44ishStowResponse\"\x17\n\x15\x44ishGetContextRequest\"\xcc\t\n\x16\x44ishGetContextResponse\x12>\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.DeviceInfoR\ndeviceInfo\x12\x41\n\x0c\x64\x65vice_state\x18\x07 \x01(\x0b\x32\x1e.SpaceX.API.Device.DeviceStateR\x0b\x64\x65viceState\x12\x31\n\x14obstruction_fraction\x18\x02 \x01(\x02R\x13obstructionFraction\x12)\n\x10obstruction_time\x18\x14 \x01(\x02R\x0fobstructionTime\x12.\n\x13obstruction_valid_s\x18\x03 \x01(\x02R\x11obstructionValidS\x12/\n\x13obstruction_current\x18\x0c \x01(\x08R\x12obstructionCurrent\x12\x17\n\x07\x63\x65ll_id\x18\x04 \x01(\rR\x06\x63\x65llId\x12\x1e\n\x0bpop_rack_id\x18\x05 \x01(\rR\tpopRackId\x12\x30\n\x14initial_satellite_id\x18\x08 \x01(\rR\x12initialSatelliteId\x12,\n\x12initial_gateway_id\x18\t \x01(\rR\x10initialGatewayId\x12$\n\x0eon_backup_beam\x18\n \x01(\x08R\x0conBackupBeam\x12-\n\x13seconds_to_slot_end\x18\x06 \x01(\x02R\x10secondsToSlotEnd\x12\x36\n\x17\x64\x65\x62ug_telemetry_enabled\x18\x0b \x01(\x08R\x15\x64\x65\x62ugTelemetryEnabled\x12;\n\x1bpop_ping_drop_rate_15s_mean\x18\r \x01(\x02R\x16popPingDropRate15sMean\x12=\n\x1cpop_ping_latency_ms_15s_mean\x18\x0e \x01(\x02R\x17popPingLatencyMs15sMean\x12>\n\x1cseconds_since_last_1s_outage\x18\x0f \x01(\x02R\x18secondsSinceLast1sOutage\x12>\n\x1cseconds_since_last_2s_outage\x18\x10 \x01(\x02R\x18secondsSinceLast2sOutage\x12>\n\x1cseconds_since_last_5s_outage\x18\x11 \x01(\x02R\x18secondsSinceLast5sOutage\x12@\n\x1dseconds_since_last_15s_outage\x18\x12 \x01(\x02R\x19secondsSinceLast15sOutage\x12@\n\x1dseconds_since_last_60s_outage\x18\x13 \x01(\x02R\x19secondsSinceLast60sOutage\x12[\n\x10\x64isablement_code\x18\x15 \x01(\x0e\x32\x30.SpaceX.API.Satellites.Network.UtDisablementCodeR\x0f\x64isablementCode\x12-\n\x13ku_mac_active_ratio\x18\x16 \x01(\x02R\x10kuMacActiveRatio\"\x9b\x03\n\nDishOutage\x12\x39\n\x05\x63\x61use\x18\x01 \x01(\x0e\x32#.SpaceX.API.Device.DishOutage.CauseR\x05\x63\x61use\x12,\n\x12start_timestamp_ns\x18\x02 \x01(\x03R\x10startTimestampNs\x12\x1f\n\x0b\x64uration_ns\x18\x03 \x01(\x04R\ndurationNs\x12\x1d\n\ndid_switch\x18\x04 \x01(\x08R\tdidSwitch\"\xe3\x01\n\x05\x43\x61use\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x42OOTING\x10\x01\x12\n\n\x06STOWED\x10\x02\x12\x14\n\x10THERMAL_SHUTDOWN\x10\x03\x12\x0f\n\x0bNO_SCHEDULE\x10\x04\x12\x0b\n\x07NO_SATS\x10\x05\x12\x0e\n\nOBSTRUCTED\x10\x06\x12\x0f\n\x0bNO_DOWNLINK\x10\x07\x12\x0c\n\x08NO_PINGS\x10\x08\x12\x15\n\x11\x41\x43TUATOR_ACTIVITY\x10\t\x12\x0e\n\nCABLE_TEST\x10\n\x12\x0c\n\x08SLEEPING\x10\x0b\x12\x1c\n\x18MOVING_WHILE_NOT_ALLOWED\x10\x0c\"\xd8\x02\n\x16\x44ishGetHistoryResponse\x12\x18\n\x07\x63urrent\x18\x01 \x01(\x04R\x07\x63urrent\x12,\n\x12pop_ping_drop_rate\x18\xe9\x07 \x03(\x02R\x0fpopPingDropRate\x12.\n\x13pop_ping_latency_ms\x18\xea\x07 \x03(\x02R\x10popPingLatencyMs\x12\x37\n\x17\x64ownlink_throughput_bps\x18\xeb\x07 \x03(\x02R\x15\x64ownlinkThroughputBps\x12\x33\n\x15uplink_throughput_bps\x18\xec\x07 \x03(\x02R\x13uplinkThroughputBps\x12\x38\n\x07outages\x18\xf1\x07 \x03(\x0b\x32\x1d.SpaceX.API.Device.DishOutageR\x07outagesJ\x06\x08\xed\x07\x10\xee\x07J\x06\x08\xee\x07\x10\xef\x07J\x06\x08\xef\x07\x10\xf0\x07J\x06\x08\xf0\x07\x10\xf1\x07\"\xca\x10\n\x15\x44ishGetStatusResponse\x12>\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.DeviceInfoR\ndeviceInfo\x12\x41\n\x0c\x64\x65vice_state\x18\x02 \x01(\x0b\x32\x1e.SpaceX.API.Device.DeviceStateR\x0b\x64\x65viceState\x12\x36\n\x06\x61lerts\x18\xed\x07 \x01(\x0b\x32\x1d.SpaceX.API.Device.DishAlertsR\x06\x61lerts\x12\x36\n\x06outage\x18\xf6\x07 \x01(\x0b\x32\x1d.SpaceX.API.Device.DishOutageR\x06outage\x12=\n\tgps_stats\x18\xf7\x07 \x01(\x0b\x32\x1f.SpaceX.API.Device.DishGpsStatsR\x08gpsStats\x12\x43\n\x1eseconds_to_first_nonempty_slot\x18\xea\x07 \x01(\x02R\x1asecondsToFirstNonemptySlot\x12,\n\x12pop_ping_drop_rate\x18\xeb\x07 \x01(\x02R\x0fpopPingDropRate\x12\x37\n\x17\x64ownlink_throughput_bps\x18\xef\x07 \x01(\x02R\x15\x64ownlinkThroughputBps\x12\x33\n\x15uplink_throughput_bps\x18\xf0\x07 \x01(\x02R\x13uplinkThroughputBps\x12.\n\x13pop_ping_latency_ms\x18\xf1\x07 \x01(\x02R\x10popPingLatencyMs\x12U\n\x11obstruction_stats\x18\xec\x07 \x01(\x0b\x32\'.SpaceX.API.Device.DishObstructionStatsR\x10obstructionStats\x12&\n\x0estow_requested\x18\xf2\x07 \x01(\x08R\rstowRequested\x12\x33\n\x15\x62oresight_azimuth_deg\x18\xf3\x07 \x01(\x02R\x13\x62oresightAzimuthDeg\x12\x37\n\x17\x62oresight_elevation_deg\x18\xf4\x07 \x01(\x02R\x15\x62oresightElevationDeg\x12%\n\x0e\x65th_speed_mbps\x18\xf8\x07 \x01(\x05R\x0c\x65thSpeedMbps\x12L\n\x0emobility_class\x18\xf9\x07 \x01(\x0e\x32$.SpaceX.API.Device.UserMobilityClassR\rmobilityClass\x12\x37\n\x18is_snr_above_noise_floor\x18\xfa\x07 \x01(\x08R\x14isSnrAboveNoiseFloor\x12\x46\n\x0cready_states\x18\xfb\x07 \x01(\x0b\x32\".SpaceX.API.Device.DishReadyStatesR\x0breadyStates\x12P\n\x10\x63lass_of_service\x18\xfc\x07 \x01(\x0e\x32%.SpaceX.API.Device.UserClassOfServiceR\x0e\x63lassOfService\x12[\n\x15software_update_state\x18\xfd\x07 \x01(\x0e\x32&.SpaceX.API.Device.SoftwareUpdateStateR\x13softwareUpdateState\x12\x33\n\x15swupdate_reboot_ready\x18\x86\x08 \x01(\x08R\x13swupdateRebootReady\x12[\n\x15software_update_stats\x18\x82\x08 \x01(\x0b\x32&.SpaceX.API.Device.SoftwareUpdateStatsR\x13softwareUpdateStats\x12K\n\x0f\x61lignment_stats\x18\x83\x08 \x01(\x0b\x32!.SpaceX.API.Device.AlignmentStatsR\x0e\x61lignmentStats\x12\x36\n\x17is_snr_persistently_low\x18\xfe\x07 \x01(\x08R\x14isSnrPersistentlyLow\x12\x45\n\rhas_actuators\x18\xff\x07 \x01(\x0e\x32\x1f.SpaceX.API.Device.HasActuatorsR\x0chasActuators\x12\\\n\x10\x64isablement_code\x18\x80\x08 \x01(\x0e\x32\x30.SpaceX.API.Satellites.Network.UtDisablementCodeR\x0f\x64isablementCode\x12\'\n\x0fhas_signed_cals\x18\x81\x08 \x01(\x08R\rhasSignedCals\x12\x36\n\x06\x63onfig\x18\xd0\x0f \x01(\x0b\x32\x1d.SpaceX.API.Device.DishConfigR\x06\x63onfig\x12y\n\x1finitialization_duration_seconds\x18\x84\x08 \x01(\x0b\x32\x30.SpaceX.API.Device.InitializationDurationSecondsR\x1dinitializationDurationSeconds\x12)\n\x10is_cell_disabled\x18\x85\x08 \x01(\x08R\x0eisCellDisabled\x12S\n&seconds_until_swupdate_reboot_possible\x18\x87\x08 \x01(\x05R\"secondsUntilSwupdateRebootPossible\x12,\n\x11\x63onnected_routers\x18\x90\x08 \x03(\tR\x10\x63onnectedRoutersJ\x06\x08\xe9\x07\x10\xea\x07J\x06\x08\xee\x07\x10\xef\x07J\x06\x08\xf5\x07\x10\xf6\x07\"\x1e\n\x1c\x44ishGetObstructionMapRequest\"\xbb\x01\n\x1d\x44ishGetObstructionMapResponse\x12\x19\n\x08num_rows\x18\x01 \x01(\rR\x07numRows\x12\x19\n\x08num_cols\x18\x02 \x01(\rR\x07numCols\x12\x10\n\x03snr\x18\x03 \x03(\x02R\x03snr\x12.\n\x11min_elevation_deg\x18\x04 \x01(\x02\x42\x02\x18\x01R\x0fminElevationDeg\x12\"\n\rmax_theta_deg\x18\x05 \x01(\x02R\x0bmaxThetaDeg\"\xd4\x06\n\nDishAlerts\x12!\n\x0cmotors_stuck\x18\x01 \x01(\x08R\x0bmotorsStuck\x12)\n\x10thermal_throttle\x18\x03 \x01(\x08R\x0fthermalThrottle\x12)\n\x10thermal_shutdown\x18\x02 \x01(\x08R\x0fthermalShutdown\x12\x33\n\x16mast_not_near_vertical\x18\x05 \x01(\x08R\x13mastNotNearVertical\x12/\n\x13unexpected_location\x18\x04 \x01(\x08R\x12unexpectedLocation\x12\x30\n\x14slow_ethernet_speeds\x18\x06 \x01(\x08R\x12slowEthernetSpeeds\x12\x37\n\x18slow_ethernet_speeds_100\x18\x12 \x01(\x08R\x15slowEthernetSpeeds100\x12\x18\n\x07roaming\x18\x07 \x01(\x08R\x07roaming\x12\'\n\x0finstall_pending\x18\x08 \x01(\x08R\x0einstallPending\x12\x1d\n\nis_heating\x18\t \x01(\x08R\tisHeating\x12\x41\n\x1dpower_supply_thermal_throttle\x18\n \x01(\x08R\x1apowerSupplyThermalThrottle\x12+\n\x12is_power_save_idle\x18\x0b \x01(\x08R\x0fisPowerSaveIdle\x12\x35\n\x17moving_while_not_mobile\x18\x0c \x01(\x08R\x14movingWhileNotMobile\x12:\n\x1amoving_too_fast_for_policy\x18\x0f \x01(\x08R\x16movingTooFastForPolicy\x12&\n\x0f\x64\x62\x66_telem_stale\x18\x0e \x01(\x08R\rdbfTelemStale\x12*\n\x11low_motor_current\x18\x10 \x01(\x08R\x0flowMotorCurrent\x12=\n\x1blower_signal_than_predicted\x18\x11 \x01(\x08R\x18lowerSignalThanPredictedJ\x04\x08\r\x10\x0eR\x1emoving_fast_while_not_aviation\"\x81\x01\n\x0f\x44ishReadyStates\x12\x12\n\x04\x63\x61\x64y\x18\x01 \x01(\x08R\x04\x63\x61\x64y\x12\x10\n\x03scp\x18\x02 \x01(\x08R\x03scp\x12\x12\n\x04l1l2\x18\x03 \x01(\x08R\x04l1l2\x12\x12\n\x04xphy\x18\x04 \x01(\x08R\x04xphy\x12\x10\n\x03\x61\x61p\x18\x05 \x01(\x08R\x03\x61\x61p\x12\x0e\n\x02rf\x18\x06 \x01(\x08R\x02rf\"\x94\x01\n\x0c\x44ishGpsStats\x12\x1b\n\tgps_valid\x18\x01 \x01(\x08R\x08gpsValid\x12\x19\n\x08gps_sats\x18\x02 \x01(\rR\x07gpsSats\x12+\n\x12no_sats_after_ttff\x18\x03 \x01(\x08R\x0fnoSatsAfterTtff\x12\x1f\n\x0binhibit_gps\x18\x04 \x01(\x08R\ninhibitGps\"\xab\x01\n\x13SoftwareUpdateStats\x12Z\n\x15software_update_state\x18\x01 \x01(\x0e\x32&.SpaceX.API.Device.SoftwareUpdateStateR\x13softwareUpdateState\x12\x38\n\x18software_update_progress\x18\x02 \x01(\x02R\x16softwareUpdateProgress\"\xdd\x04\n\x0e\x41lignmentStats\x12\x44\n\rhas_actuators\x18\x01 \x01(\x0e\x32\x1f.SpaceX.API.Device.HasActuatorsR\x0chasActuators\x12G\n\x0e\x61\x63tuator_state\x18\x02 \x01(\x0e\x32 .SpaceX.API.Device.ActuatorStateR\ractuatorState\x12$\n\x0etilt_angle_deg\x18\x03 \x01(\x02R\x0ctiltAngleDeg\x12\x32\n\x15\x62oresight_azimuth_deg\x18\x04 \x01(\x02R\x13\x62oresightAzimuthDeg\x12\x36\n\x17\x62oresight_elevation_deg\x18\x05 \x01(\x02R\x15\x62oresightElevationDeg\x12\x41\n\x1d\x64\x65sired_boresight_azimuth_deg\x18\x08 \x01(\x02R\x1a\x64\x65siredBoresightAzimuthDeg\x12\x45\n\x1f\x64\x65sired_boresight_elevation_deg\x18\t \x01(\x02R\x1c\x64\x65siredBoresightElevationDeg\x12\x66\n\x19\x61ttitude_estimation_state\x18\x06 \x01(\x0e\x32*.SpaceX.API.Device.AttitudeEstimationStateR\x17\x61ttitudeEstimationState\x12\x38\n\x18\x61ttitude_uncertainty_deg\x18\x07 \x01(\x02R\x16\x61ttitudeUncertaintyDeg\"\x96\x04\n\x14\x44ishObstructionStats\x12\x31\n\x14\x63urrently_obstructed\x18\x05 \x01(\x08R\x13\x63urrentlyObstructed\x12/\n\x13\x66raction_obstructed\x18\x01 \x01(\x02R\x12\x66ractionObstructed\x12\'\n\x0ftime_obstructed\x18\t \x01(\x02R\x0etimeObstructed\x12\x17\n\x07valid_s\x18\x04 \x01(\x02R\x06validS\x12#\n\rpatches_valid\x18\n \x01(\rR\x0cpatchesValid\x12N\n$avg_prolonged_obstruction_duration_s\x18\x06 \x01(\x02R avgProlongedObstructionDurationS\x12N\n$avg_prolonged_obstruction_interval_s\x18\x07 \x01(\x02R avgProlongedObstructionIntervalS\x12\x45\n\x1f\x61vg_prolonged_obstruction_valid\x18\x08 \x01(\x08R\x1c\x61vgProlongedObstructionValidJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x06\x08\xee\x07\x10\xef\x07R\x19wedge_fraction_obstructedR\x1dwedge_abs_fraction_obstructed\"\xb1\x03\n\x1dInitializationDurationSeconds\x12\x37\n\x17\x61ttitude_initialization\x18\x01 \x01(\x05R\x16\x61ttitudeInitialization\x12%\n\x0e\x62urst_detected\x18\x02 \x01(\x05R\rburstDetected\x12#\n\rekf_converged\x18\x03 \x01(\x05R\x0c\x65kfConverged\x12!\n\x0c\x66irst_cplane\x18\x04 \x01(\x05R\x0b\x66irstCplane\x12$\n\x0e\x66irst_pop_ping\x18\x05 \x01(\x05R\x0c\x66irstPopPing\x12\x1b\n\tgps_valid\x18\x06 \x01(\x05R\x08gpsValid\x12\x32\n\x15initial_network_entry\x18\x07 \x01(\x05R\x13initialNetworkEntry\x12)\n\x10network_schedule\x18\x08 \x01(\x05R\x0fnetworkSchedule\x12\x19\n\x08rf_ready\x18\t \x01(\x05R\x07rfReady\x12+\n\x11stable_connection\x18\n \x01(\x05R\x10stableConnection\"T\n\x18\x44ishAuthenticateResponse\x12\x38\n\x04\x64ish\x18\x02 \x01(\x0b\x32$.SpaceX.API.Device.ChallengeResponseR\x04\x64ish\"-\n\x0fSelfTestRequest\x12\x1a\n\x08\x64\x65tailed\x18\x01 \x01(\x08R\x08\x64\x65tailed\"B\n\x10SelfTestResponse\x12\x16\n\x06passed\x18\x01 \x01(\x08R\x06passed\x12\x16\n\x06report\x18\x02 \x01(\tR\x06report\"\x1a\n\x18StartDishSelfTestRequest\"\x1b\n\x19StartDishSelfTestResponse\"\x8f\x02\n\x12SetTestModeRequest\x12\x45\n\x07rf_mode\x18\x01 \x01(\x0e\x32,.SpaceX.API.Device.SetTestModeRequest.RfModeR\x06rfMode\x12\x39\n\x19\x64isable_loss_of_comm_fdir\x18\xe9\x07 \x01(\x08R\x15\x64isableLossOfCommFdir\x12\x33\n\x15\x65nable_rules_override\x18\xea\x07 \x01(\x08R\x13\x65nableRulesOverride\"B\n\x06RfMode\x12\x06\n\x02RX\x10\x00\x12\x08\n\x04IDLE\x10\x01\x12\x06\n\x02TX\x10\x02\x12\x07\n\x03\x43\x41L\x10\x03\x12\x08\n\x04USER\x10\x04\x12\x0b\n\x06NORMAL\x10\xa4\x03\"\x15\n\x13SetTestModeResponse\"V\n\x14\x44ishSetConfigRequest\x12>\n\x0b\x64ish_config\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.DishConfigR\ndishConfig\"f\n\x15\x44ishSetConfigResponse\x12M\n\x13updated_dish_config\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.DishConfigR\x11updatedDishConfig\"\x16\n\x14\x44ishGetConfigRequest\"W\n\x15\x44ishGetConfigResponse\x12>\n\x0b\x64ish_config\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.DishConfigR\ndishConfig\"8\n\x15\x44ishInhibitGpsRequest\x12\x1f\n\x0binhibit_gps\x18\x01 \x01(\x08R\ninhibitGps\"9\n\x16\x44ishInhibitGpsResponse\x12\x1f\n\x0binhibit_gps\x18\x01 \x01(\x08R\ninhibitGps\"$\n\x12\x44ishGetDataRequest\x12\x0e\n\x02id\x18\x01 \x01(\rR\x02id\" \n\x1e\x44ishClearObstructionMapRequest\"!\n\x1f\x44ishClearObstructionMapResponse\"e\n\x1b\x44ishActivateRssiScanRequest\x12\x46\n\nscan_query\x18\x01 \x01(\x0b\x32\'.SpaceX.API.Device.DishActivateRssiScanR\tscanQuery\"8\n\x1c\x44ishActivateRssiScanResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\x1e\n\x1c\x44ishGetRssiScanResultRequest\"a\n\x1d\x44ishGetRssiScanResultResponse\x12@\n\x06result\x18\x01 \x01(\x0b\x32(.SpaceX.API.Device.DishGetRssiScanResultR\x06result\"\x19\n\x17\x44ishFactoryResetRequest\"\x1a\n\x18\x44ishFactoryResetResponse\".\n\x12ResetButtonRequest\x12\x18\n\x07pressed\x18\x01 \x01(\x08R\x07pressed\"\x15\n\x13ResetButtonResponse*<\n\x11UserMobilityClass\x12\x0e\n\nSTATIONARY\x10\x00\x12\x0b\n\x07NOMADIC\x10\x01\x12\n\n\x06MOBILE\x10\x02*\xac\x01\n\x13SoftwareUpdateState\x12!\n\x1dSOFTWARE_UPDATE_STATE_UNKNOWN\x10\x00\x12\x08\n\x04IDLE\x10\x01\x12\x0c\n\x08\x46\x45TCHING\x10\x02\x12\r\n\tPRE_CHECK\x10\x03\x12\x0b\n\x07WRITING\x10\x04\x12\x0e\n\nPOST_CHECK\x10\x05\x12\x13\n\x0fREBOOT_REQUIRED\x10\x06\x12\x0c\n\x08\x44ISABLED\x10\x07\x12\x0b\n\x07\x46\x41ULTED\x10\x08*\x7f\n\x12UserClassOfService\x12!\n\x1dUNKNOWN_USER_CLASS_OF_SERVICE\x10\x00\x12\x0c\n\x08\x43ONSUMER\x10\x01\x12\x0c\n\x08\x42USINESS\x10\x02\x12\x11\n\rBUSINESS_PLUS\x10\x03\x12\x17\n\x13\x43OMMERCIAL_AVIATION\x10\x04*V\n\x0cHasActuators\x12\x19\n\x15HAS_ACTUATORS_UNKNOWN\x10\x00\x12\x15\n\x11HAS_ACTUATORS_YES\x10\x01\x12\x14\n\x10HAS_ACTUATORS_NO\x10\x02*\xf2\x02\n\rActuatorState\x12\x17\n\x13\x41\x43TUATOR_STATE_IDLE\x10\x00\x12\x1c\n\x18\x41\x43TUATOR_STATE_FULL_TILT\x10\x01\x12\x19\n\x15\x41\x43TUATOR_STATE_ROTATE\x10\x02\x12\x17\n\x13\x41\x43TUATOR_STATE_TILT\x10\x03\x12\"\n\x1e\x41\x43TUATOR_STATE_UNWRAP_POSITIVE\x10\x04\x12\"\n\x1e\x41\x43TUATOR_STATE_UNWRAP_NEGATIVE\x10\x05\x12!\n\x1d\x41\x43TUATOR_STATE_TILT_TO_STOWED\x10\x06\x12\x1a\n\x16\x41\x43TUATOR_STATE_FAULTED\x10\x07\x12\"\n\x1e\x41\x43TUATOR_STATE_WAIT_TIL_STATIC\x10\x08\x12+\n\'ACTUATOR_STATE_DRIVE_TO_MOBILE_POSITION\x10\t\x12\x1e\n\x1a\x41\x43TUATOR_STATE_MOBILE_WAIT\x10\n*\x81\x01\n\x17\x41ttitudeEstimationState\x12\x10\n\x0c\x46ILTER_RESET\x10\x00\x12\x16\n\x12\x46ILTER_UNCONVERGED\x10\x01\x12\x14\n\x10\x46ILTER_CONVERGED\x10\x02\x12\x12\n\x0e\x46ILTER_FAULTED\x10\x03\x12\x12\n\x0e\x46ILTER_INVALID\x10\x04*C\n\tDishState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tCONNECTED\x10\x01\x12\r\n\tSEARCHING\x10\x02\x12\x0b\n\x07\x42OOTING\x10\x03\x42\xd3\x01\n\x15\x63om.SpaceX.API.DeviceB\tDishProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.dish_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\tDishProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_DISHGETOBSTRUCTIONMAPRESPONSE'].fields_by_name['min_elevation_deg']._loaded_options = None
  _globals['_DISHGETOBSTRUCTIONMAPRESPONSE'].fields_by_name['min_elevation_deg']._serialized_options = b'\030\001'
  _globals['_USERMOBILITYCLASS']._serialized_start=9035
  _globals['_USERMOBILITYCLASS']._serialized_end=9095
  _globals['_SOFTWAREUPDATESTATE']._serialized_start=9098
  _globals['_SOFTWAREUPDATESTATE']._serialized_end=9270
  _globals['_USERCLASSOFSERVICE']._serialized_start=9272
  _globals['_USERCLASSOFSERVICE']._serialized_end=9399
  _globals['_HASACTUATORS']._serialized_start=9401
  _globals['_HASACTUATORS']._serialized_end=9487
  _globals['_ACTUATORSTATE']._serialized_start=9490
  _globals['_ACTUATORSTATE']._serialized_end=9860
  _globals['_ATTITUDEESTIMATIONSTATE']._serialized_start=9863
  _globals['_ATTITUDEESTIMATIONSTATE']._serialized_end=9992
  _globals['_DISHSTATE']._serialized_start=9994
  _globals['_DISHSTATE']._serialized_end=10061
  _globals['_DISHSTOWREQUEST']._serialized_start=213
  _globals['_DISHSTOWREQUEST']._serialized_end=254
  _globals['_DISHSTOWRESPONSE']._serialized_start=256
  _globals['_DISHSTOWRESPONSE']._serialized_end=274
  _globals['_DISHGETCONTEXTREQUEST']._serialized_start=276
  _globals['_DISHGETCONTEXTREQUEST']._serialized_end=299
  _globals['_DISHGETCONTEXTRESPONSE']._serialized_start=302
  _globals['_DISHGETCONTEXTRESPONSE']._serialized_end=1530
  _globals['_DISHOUTAGE']._serialized_start=1533
  _globals['_DISHOUTAGE']._serialized_end=1944
  _globals['_DISHOUTAGE_CAUSE']._serialized_start=1717
  _globals['_DISHOUTAGE_CAUSE']._serialized_end=1944
  _globals['_DISHGETHISTORYRESPONSE']._serialized_start=1947
  _globals['_DISHGETHISTORYRESPONSE']._serialized_end=2291
  _globals['_DISHGETSTATUSRESPONSE']._serialized_start=2294
  _globals['_DISHGETSTATUSRESPONSE']._serialized_end=4416
  _globals['_DISHGETOBSTRUCTIONMAPREQUEST']._serialized_start=4418
  _globals['_DISHGETOBSTRUCTIONMAPREQUEST']._serialized_end=4448
  _globals['_DISHGETOBSTRUCTIONMAPRESPONSE']._serialized_start=4451
  _globals['_DISHGETOBSTRUCTIONMAPRESPONSE']._serialized_end=4638
  _globals['_DISHALERTS']._serialized_start=4641
  _globals['_DISHALERTS']._serialized_end=5493
  _globals['_DISHREADYSTATES']._serialized_start=5496
  _globals['_DISHREADYSTATES']._serialized_end=5625
  _globals['_DISHGPSSTATS']._serialized_start=5628
  _globals['_DISHGPSSTATS']._serialized_end=5776
  _globals['_SOFTWAREUPDATESTATS']._serialized_start=5779
  _globals['_SOFTWAREUPDATESTATS']._serialized_end=5950
  _globals['_ALIGNMENTSTATS']._serialized_start=5953
  _globals['_ALIGNMENTSTATS']._serialized_end=6558
  _globals['_DISHOBSTRUCTIONSTATS']._serialized_start=6561
  _globals['_DISHOBSTRUCTIONSTATS']._serialized_end=7095
  _globals['_INITIALIZATIONDURATIONSECONDS']._serialized_start=7098
  _globals['_INITIALIZATIONDURATIONSECONDS']._serialized_end=7531
  _globals['_DISHAUTHENTICATERESPONSE']._serialized_start=7533
  _globals['_DISHAUTHENTICATERESPONSE']._serialized_end=7617
  _globals['_SELFTESTREQUEST']._serialized_start=7619
  _globals['_SELFTESTREQUEST']._serialized_end=7664
  _globals['_SELFTESTRESPONSE']._serialized_start=7666
  _globals['_SELFTESTRESPONSE']._serialized_end=7732
  _globals['_STARTDISHSELFTESTREQUEST']._serialized_start=7734
  _globals['_STARTDISHSELFTESTREQUEST']._serialized_end=7760
  _globals['_STARTDISHSELFTESTRESPONSE']._serialized_start=7762
  _globals['_STARTDISHSELFTESTRESPONSE']._serialized_end=7789
  _globals['_SETTESTMODEREQUEST']._serialized_start=7792
  _globals['_SETTESTMODEREQUEST']._serialized_end=8063
  _globals['_SETTESTMODEREQUEST_RFMODE']._serialized_start=7997
  _globals['_SETTESTMODEREQUEST_RFMODE']._serialized_end=8063
  _globals['_SETTESTMODERESPONSE']._serialized_start=8065
  _globals['_SETTESTMODERESPONSE']._serialized_end=8086
  _globals['_DISHSETCONFIGREQUEST']._serialized_start=8088
  _globals['_DISHSETCONFIGREQUEST']._serialized_end=8174
  _globals['_DISHSETCONFIGRESPONSE']._serialized_start=8176
  _globals['_DISHSETCONFIGRESPONSE']._serialized_end=8278
  _globals['_DISHGETCONFIGREQUEST']._serialized_start=8280
  _globals['_DISHGETCONFIGREQUEST']._serialized_end=8302
  _globals['_DISHGETCONFIGRESPONSE']._serialized_start=8304
  _globals['_DISHGETCONFIGRESPONSE']._serialized_end=8391
  _globals['_DISHINHIBITGPSREQUEST']._serialized_start=8393
  _globals['_DISHINHIBITGPSREQUEST']._serialized_end=8449
  _globals['_DISHINHIBITGPSRESPONSE']._serialized_start=8451
  _globals['_DISHINHIBITGPSRESPONSE']._serialized_end=8508
  _globals['_DISHGETDATAREQUEST']._serialized_start=8510
  _globals['_DISHGETDATAREQUEST']._serialized_end=8546
  _globals['_DISHCLEAROBSTRUCTIONMAPREQUEST']._serialized_start=8548
  _globals['_DISHCLEAROBSTRUCTIONMAPREQUEST']._serialized_end=8580
  _globals['_DISHCLEAROBSTRUCTIONMAPRESPONSE']._serialized_start=8582
  _globals['_DISHCLEAROBSTRUCTIONMAPRESPONSE']._serialized_end=8615
  _globals['_DISHACTIVATERSSISCANREQUEST']._serialized_start=8617
  _globals['_DISHACTIVATERSSISCANREQUEST']._serialized_end=8718
  _globals['_DISHACTIVATERSSISCANRESPONSE']._serialized_start=8720
  _globals['_DISHACTIVATERSSISCANRESPONSE']._serialized_end=8776
  _globals['_DISHGETRSSISCANRESULTREQUEST']._serialized_start=8778
  _globals['_DISHGETRSSISCANRESULTREQUEST']._serialized_end=8808
  _globals['_DISHGETRSSISCANRESULTRESPONSE']._serialized_start=8810
  _globals['_DISHGETRSSISCANRESULTRESPONSE']._serialized_end=8907
  _globals['_DISHFACTORYRESETREQUEST']._serialized_start=8909
  _globals['_DISHFACTORYRESETREQUEST']._serialized_end=8934
  _globals['_DISHFACTORYRESETRESPONSE']._serialized_start=8936
  _globals['_DISHFACTORYRESETRESPONSE']._serialized_end=8962
  _globals['_RESETBUTTONREQUEST']._serialized_start=8964
  _globals['_RESETBUTTONREQUEST']._serialized_end=9010
  _globals['_RESETBUTTONRESPONSE']._serialized_start=9012
  _globals['_RESETBUTTONRESPONSE']._serialized_end=9033
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BootReason(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    BOOT_REASON_UNKNOWN: _ClassVar[BootReason]
    FORGOTTEN: _ClassVar[BootReason]
    POWER_CYCLE: _ClassVar[BootReason]
    COMMAND: _ClassVar[BootReason]
    SOFTWARE_UPDATE: _ClassVar[BootReason]
    CONFIG_UPDATE: _ClassVar[BootReason]
    UPTIME_FDIR: _ClassVar[BootReason]
    REPEATER_FDIR: _ClassVar[BootReason]
    AVIATION_ETH_WAN_FDIR: _ClassVar[BootReason]
    KERNEL_PANIC: _ClassVar[BootReason]
    INTENTIONAL_KERNEL_PANIC: _ClassVar[BootReason]
    MCU_BRINGUP_FAILED_FDIR: _ClassVar[BootReason]
    AVIATION_OUTAGE_FDIR: _ClassVar[BootReason]
    SOFTWARE_WATCHDOG: _ClassVar[BootReason]
BOOT_REASON_UNKNOWN: BootReason
FORGOTTEN: BootReason
POWER_CYCLE: BootReason
COMMAND: BootReason
SOFTWARE_UPDATE: BootReason
CONFIG_UPDATE: BootReason
UPTIME_FDIR: BootReason
REPEATER_FDIR: BootReason
AVIATION_ETH_WAN_FDIR: BootReason
KERNEL_PANIC: BootReason
INTENTIONAL_KERNEL_PANIC: BootReason
MCU_BRINGUP_FAILED_FDIR: BootReason
AVIATION_OUTAGE_FDIR: BootReason
SOFTWARE_WATCHDOG: BootReason

class DeviceInfo(_message.Message):
    __slots__ = ("id", "hardware_version", "board_rev", "software_version", "manufactured_version", "generation_number", "country_code", "utc_offset_s", "software_partitions_equal", "is_dev", "bootcount", "anti_rollback_version", "is_hitl", "boot", "dish_cohoused")
    ID_FIELD_NUMBER: _ClassVar[int]
    HARDWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    BOARD_REV_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    MANUFACTURED_VERSION_FIELD_NUMBER: _ClassVar[int]
    GENERATION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    UTC_OFFSET_S_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_PARTITIONS_EQUAL_FIELD_NUMBER: _ClassVar[int]
    IS_DEV_FIELD_NUMBER: _ClassVar[int]
    BOOTCOUNT_FIELD_NUMBER: _ClassVar[int]
    ANTI_ROLLBACK_VERSION_FIELD_NUMBER: _ClassVar[int]
    IS_HITL_FIELD_NUMBER: _ClassVar[int]
    BOOT_FIELD_NUMBER: _ClassVar[int]
    DISH_COHOUSED_FIELD_NUMBER: _ClassVar[int]
    id: str
    hardware_version: str
    board_rev: int
    software_version: str
    manufactured_version: str
    generation_number: int
    country_code: str
    utc_offset_s: int
    software_partitions_equal: bool
    is_dev: bool
    bootcount: int
    anti_rollback_version: int
    is_hitl: bool
    boot: BootInfo
    dish_cohoused: bool
    def __init__(self, id: _Optional[str] = ..., hardware_version: _Optional[str] = ..., board_rev: _Optional[int] = ..., software_version: _Optional[str] = ..., manufactured_version: _Optional[str] = ..., generation_number: _Optional[int] = ..., country_code: _Optional[str] = ..., utc_offset_s: _Optional[int] = ..., software_partitions_equal: bool = ..., is_dev: bool = ..., bootcount: _Optional[int] = ..., anti_rollback_version: _Optional[int] = ..., is_hitl: bool = ..., boot: _Optional[_Union[BootInfo, _Mapping]] = ..., dish_cohoused: bool = ...) -> None: ...

class DeviceState(_message.Message):
    __slots__ = ("uptime_s",)
    UPTIME_S_FIELD_NUMBER: _ClassVar[int]
    uptime_s: int
    def __init__(self, uptime_s: _Optional[int] = ...) -> None: ...

class SignedData(_message.Message):
    __slots__ = ("data", "signature")
    DATA_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    signature: bytes
    def __init__(self, data: _Optional[bytes] = ..., signature: _Optional[bytes] = ...) -> None: ...

class GetNextIdRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetNextIdResponse(_message.Message):
    __slots__ = ("id", "epoch_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    EPOCH_ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    epoch_id: int
    def __init__(self, id: _Optional[int] = ..., epoch_id: _Optional[int] = ...) -> None: ...

class BootInfo(_message.Message):
    __slots__ = ("count_by_reason", "count_by_reason_delta", "last_reason", "last_count", "crash_boot", "crash_boot_count")
    class CountByReasonEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: int
        def __init__(self, key: _Optional[int] = ..., value: _Optional[int] = ...) -> None: ...
    class CountByReasonDeltaEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: int
        def __init__(self, key: _Optional[int] = ..., value: _Optional[int] = ...) -> None: ...
    COUNT_BY_REASON_FIELD_NUMBER: _ClassVar[int]
    COUNT_BY_REASON_DELTA_FIELD_NUMBER: _ClassVar[int]
    LAST_REASON_FIELD_NUMBER: _ClassVar[int]
    LAST_COUNT_FIELD_NUMBER: _ClassVar[int]
    CRASH_BOOT_FIELD_NUMBER: _ClassVar[int]
    CRASH_BOOT_COUNT_FIELD_NUMBER: _ClassVar[int]
    count_by_reason: _containers.ScalarMap[int, int]
    count_by_reason_delta: _containers.ScalarMap[int, int]
    last_reason: BootReason
    last_count: int
    crash_boot: bool
    crash_boot_count: int
    def __init__(self, count_by_reason: _Optional[_Mapping[int, int]] = ..., count_by_reason_delta: _Optional[_Mapping[int, int]] = ..., last_reason: _Optional[_Union[BootReason, str]] = ..., last_count: _Optional[int] = ..., crash_boot: bool = ..., crash_boot_count: _Optional[int] = ...) -> None: ...

class PingTarget(_message.Message):
    __slots__ = ("service", "location", "address")
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    service: str
    location: str
    address: str
    def __init__(self, service: _Optional[str] = ..., location: _Optional[str] = ..., address: _Optional[str] = ...) -> None: ...

class PingResult(_message.Message):
    __slots__ = ("target", "dropRate", "latencyMs")
    TARGET_FIELD_NUMBER: _ClassVar[int]
    DROPRATE_FIELD_NUMBER: _ClassVar[int]
    LATENCYMS_FIELD_NUMBER: _ClassVar[int]
    target: PingTarget
    dropRate: float
    latencyMs: float
    def __init__(self, target: _Optional[_Union[PingTarget, _Mapping]] = ..., dropRate: _Optional[float] = ..., latencyMs: _Optional[float] = ...) -> None: ...

class BondingChallenge(_message.Message):
    __slots__ = ("dish_id", "wifi_id", "nonce")
    DISH_ID_FIELD_NUMBER: _ClassVar[int]
    WIFI_ID_FIELD_NUMBER: _ClassVar[int]
    NONCE_FIELD_NUMBER: _ClassVar[int]
    dish_id: str
    wifi_id: str
    nonce: bytes
    def __init__(self, dish_id: _Optional[str] = ..., wifi_id: _Optional[str] = ..., nonce: _Optional[bytes] = ...) -> None: ...

class AuthenticateRequest(_message.Message):
    __slots__ = ("challenge",)
    CHALLENGE_FIELD_NUMBER: _ClassVar[int]
    challenge: SignedData
    def __init__(self, challenge: _Optional[_Union[SignedData, _Mapping]] = ...) -> None: ...

class ChallengeResponse(_message.Message):
    __slots__ = ("signature", "certificate_chain")
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    CERTIFICATE_CHAIN_FIELD_NUMBER: _ClassVar[int]
    signature: bytes
    certificate_chain: bytes
    def __init__(self, signature: _Optional[bytes] = ..., certificate_chain: _Optional[bytes] = ...) -> None: ...

class NetworkInterface(_message.Message):
    __slots__ = ("name", "up", "mac_address", "ipv4_addresses", "ipv6_addresses", "rx_stats", "tx_stats", "ethernet", "wifi", "bridge")
    class RxStats(_message.Message):
        __slots__ = ("bytes", "packets", "frame_errors")
        BYTES_FIELD_NUMBER: _ClassVar[int]
        PACKETS_FIELD_NUMBER: _ClassVar[int]
        FRAME_ERRORS_FIELD_NUMBER: _ClassVar[int]
        bytes: int
        packets: int
        frame_errors: int
        def __init__(self, bytes: _Optional[int] = ..., packets: _Optional[int] = ..., frame_errors: _Optional[int] = ...) -> None: ...
    class TxStats(_message.Message):
        __slots__ = ("bytes", "packets")
        BYTES_FIELD_NUMBER: _ClassVar[int]
        PACKETS_FIELD_NUMBER: _ClassVar[int]
        bytes: int
        packets: int
        def __init__(self, bytes: _Optional[int] = ..., packets: _Optional[int] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    UP_FIELD_NUMBER: _ClassVar[int]
    MAC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    IPV4_ADDRESSES_FIELD_NUMBER: _ClassVar[int]
    IPV6_ADDRESSES_FIELD_NUMBER: _ClassVar[int]
    RX_STATS_FIELD_NUMBER: _ClassVar[int]
    TX_STATS_FIELD_NUMBER: _ClassVar[int]
    ETHERNET_FIELD_NUMBER: _ClassVar[int]
    WIFI_FIELD_NUMBER: _ClassVar[int]
    BRIDGE_FIELD_NUMBER: _ClassVar[int]
    name: str
    up: bool
    mac_address: str
    ipv4_addresses: _containers.RepeatedScalarFieldContainer[str]
    ipv6_addresses: _containers.RepeatedScalarFieldContainer[str]
    rx_stats: NetworkInterface.RxStats
    tx_stats: NetworkInterface.TxStats
    ethernet: EthernetNetworkInterface
    wifi: WifiNetworkInterface
    bridge: BridgeNetworkInterface
    def __init__(self, name: _Optional[str] = ..., up: bool = ..., mac_address: _Optional[str] = ..., ipv4_addresses: _Optional[_Iterable[str]] = ..., ipv6_addresses: _Optional[_Iterable[str]] = ..., rx_stats: _Optional[_Union[NetworkInterface.RxStats, _Mapping]] = ..., tx_stats: _Optional[_Union[NetworkInterface.TxStats, _Mapping]] = ..., ethernet: _Optional[_Union[EthernetNetworkInterface, _Mapping]] = ..., wifi: _Optional[_Union[WifiNetworkInterface, _Mapping]] = ..., bridge: _Optional[_Union[BridgeNetworkInterface, _Mapping]] = ...) -> None: ...

class EthernetNetworkInterface(_message.Message):
    __slots__ = ("link_detected", "speed_mbps", "autonegotiation_on", "duplex")
    class Duplex(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN: _ClassVar[EthernetNetworkInterface.Duplex]
        HALF: _ClassVar[EthernetNetworkInterface.Duplex]
        FULL: _ClassVar[EthernetNetworkInterface.Duplex]
    UNKNOWN: EthernetNetworkInterface.Duplex
    HALF: EthernetNetworkInterface.Duplex
    FULL: EthernetNetworkInterface.Duplex
    LINK_DETECTED_FIELD_NUMBER: _ClassVar[int]
    SPEED_MBPS_FIELD_NUMBER: _ClassVar[int]
    AUTONEGOTIATION_ON_FIELD_NUMBER: _ClassVar[int]
    DUPLEX_FIELD_NUMBER: _ClassVar[int]
    link_detected: bool
    speed_mbps: int
    autonegotiation_on: bool
    duplex: EthernetNetworkInterface.Duplex
    def __init__(self, link_detected: bool = ..., speed_mbps: _Optional[int] = ..., autonegotiation_on: bool = ..., duplex: _Optional[_Union[EthernetNetworkInterface.Duplex, str]] = ...) -> None: ...

class WifiNetworkInterface(_message.Message):
    __slots__ = ("invalid_packet_counts", "channel", "missed_beacons", "link_quality", "signal_level", "noise_level")
    class InvalidPacketCounts(_message.Message):
        __slots__ = ("rx_invalid_nwid", "rx_invalid_crypt", "rx_invalid_frag", "tx_excessive_retries", "invalid_misc")
        RX_INVALID_NWID_FIELD_NUMBER: _ClassVar[int]
        RX_INVALID_CRYPT_FIELD_NUMBER: _ClassVar[int]
        RX_INVALID_FRAG_FIELD_NUMBER: _ClassVar[int]
        TX_EXCESSIVE_RETRIES_FIELD_NUMBER: _ClassVar[int]
        INVALID_MISC_FIELD_NUMBER: _ClassVar[int]
        rx_invalid_nwid: int
        rx_invalid_crypt: int
        rx_invalid_frag: int
        tx_excessive_retries: int
        invalid_misc: int
        def __init__(self, rx_invalid_nwid: _Optional[int] = ..., rx_invalid_crypt: _Optional[int] = ..., rx_invalid_frag: _Optional[int] = ..., tx_excessive_retries: _Optional[int] = ..., invalid_misc: _Optional[int] = ...) -> None: ...
    INVALID_PACKET_COUNTS_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    MISSED_BEACONS_FIELD_NUMBER: _ClassVar[int]
    LINK_QUALITY_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_LEVEL_FIELD_NUMBER: _ClassVar[int]
    NOISE_LEVEL_FIELD_NUMBER: _ClassVar[int]
    invalid_packet_counts: WifiNetworkInterface.InvalidPacketCounts
    channel: int
    missed_beacons: int
    link_quality: float
    signal_level: float
    noise_level: float
    def __init__(self, invalid_packet_counts: _Optional[_Union[WifiNetworkInterface.InvalidPacketCounts, _Mapping]] = ..., channel: _Optional[int] = ..., missed_beacons: _Optional[int] = ..., link_quality: _Optional[float] = ..., signal_level: _Optional[float] = ..., noise_level: _Optional[float] = ...) -> None: ...

class BridgeNetworkInterface(_message.Message):
    __slots__ = ("member_names",)
    MEMBER_NAMES_FIELD_NUMBER: _ClassVar[int]
    member_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, member_names: _Optional[_Iterable[str]] = ...) -> None: ...

class LLAPosition(_message.Message):
    __slots__ = ("lat", "lon", "alt")
    LAT_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    ALT_FIELD_NUMBER: _ClassVar[int]
    lat: float
    lon: float
    alt: float
    def __init__(self, lat: _Optional[float] = ..., lon: _Optional[float] = ..., alt: _Optional[float] = ...) -> None: ...

class ECEFPosition(_message.Message):
    __slots__ = ("x", "y", "z")
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    Z_FIELD_NUMBER: _ClassVar[int]
    x: float
    y: float
    z: float
    def __init__(self, x: _Optional[float] = ..., y: _Optional[float] = ..., z: _Optional[float] = ...) -> None: ...

class InitiateRemoteSshRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class InitiateRemoteSshResponse(_message.Message):
    __slots__ = ("port", "address", "stsafe")
    PORT_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STSAFE_FIELD_NUMBER: _ClassVar[int]
    port: int
    address: str
    stsafe: bytes
    def __init__(self, port: _Optional[int] = ..., address: _Optional[str] = ..., stsafe: _Optional[bytes] = ...) -> None: ...

class SoftwareUpdateRequest(_message.Message):
    __slots__ = ("stream_id", "data", "open", "close")
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    OPEN_FIELD_NUMBER: _ClassVar[int]
    CLOSE_FIELD_NUMBER: _ClassVar[int]
    stream_id: int
    data: bytes
    open: bool
    close: bool
    def __init__(self, stream_id: _Optional[int] = ..., data: _Optional[bytes] = ..., open: bool = ..., close: bool = ...) -> None: ...

class SoftwareUpdateResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...
